from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.column_expected_numbers_in_use_count_check_spec import (
        ColumnExpectedNumbersInUseCountCheckSpec,
    )
    from ..models.column_invalid_latitude_count_check_spec import (
        ColumnInvalidLatitudeCountCheckSpec,
    )
    from ..models.column_invalid_longitude_count_check_spec import (
        ColumnInvalidLongitudeCountCheckSpec,
    )
    from ..models.column_max_in_range_check_spec import ColumnMaxInRangeCheckSpec
    from ..models.column_mean_in_range_check_spec import ColumnMeanInRangeCheckSpec
    from ..models.column_median_in_range_check_spec import ColumnMedianInRangeCheckSpec
    from ..models.column_min_in_range_check_spec import ColumnMinInRangeCheckSpec
    from ..models.column_negative_count_check_spec import ColumnNegativeCountCheckSpec
    from ..models.column_negative_percent_check_spec import (
        ColumnNegativePercentCheckSpec,
    )
    from ..models.column_non_negative_count_check_spec import (
        ColumnNonNegativeCountCheckSpec,
    )
    from ..models.column_non_negative_percent_check_spec import (
        ColumnNonNegativePercentCheckSpec,
    )
    from ..models.column_number_value_in_set_percent_check_spec import (
        ColumnNumberValueInSetPercentCheckSpec,
    )
    from ..models.column_percentile_10_in_range_check_spec import (
        ColumnPercentile10InRangeCheckSpec,
    )
    from ..models.column_percentile_25_in_range_check_spec import (
        ColumnPercentile25InRangeCheckSpec,
    )
    from ..models.column_percentile_75_in_range_check_spec import (
        ColumnPercentile75InRangeCheckSpec,
    )
    from ..models.column_percentile_90_in_range_check_spec import (
        ColumnPercentile90InRangeCheckSpec,
    )
    from ..models.column_percentile_in_range_check_spec import (
        ColumnPercentileInRangeCheckSpec,
    )
    from ..models.column_population_stddev_in_range_check_spec import (
        ColumnPopulationStddevInRangeCheckSpec,
    )
    from ..models.column_population_variance_in_range_check_spec import (
        ColumnPopulationVarianceInRangeCheckSpec,
    )
    from ..models.column_sample_stddev_in_range_check_spec import (
        ColumnSampleStddevInRangeCheckSpec,
    )
    from ..models.column_sample_variance_in_range_check_spec import (
        ColumnSampleVarianceInRangeCheckSpec,
    )
    from ..models.column_sum_in_range_check_spec import ColumnSumInRangeCheckSpec
    from ..models.column_valid_latitude_percent_check_spec import (
        ColumnValidLatitudePercentCheckSpec,
    )
    from ..models.column_valid_longitude_percent_check_spec import (
        ColumnValidLongitudePercentCheckSpec,
    )
    from ..models.column_value_above_max_value_count_check_spec import (
        ColumnValueAboveMaxValueCountCheckSpec,
    )
    from ..models.column_value_above_max_value_percent_check_spec import (
        ColumnValueAboveMaxValuePercentCheckSpec,
    )
    from ..models.column_value_below_min_value_count_check_spec import (
        ColumnValueBelowMinValueCountCheckSpec,
    )
    from ..models.column_value_below_min_value_percent_check_spec import (
        ColumnValueBelowMinValuePercentCheckSpec,
    )
    from ..models.column_values_in_range_integers_percent_check_spec import (
        ColumnValuesInRangeIntegersPercentCheckSpec,
    )
    from ..models.column_values_in_range_numeric_percent_check_spec import (
        ColumnValuesInRangeNumericPercentCheckSpec,
    )


T = TypeVar("T", bound="ColumnNumericMonthlyPartitionedChecksSpec")


@attr.s(auto_attribs=True)
class ColumnNumericMonthlyPartitionedChecksSpec:
    """
    Attributes:
        monthly_partition_negative_count (Union[Unset, ColumnNegativeCountCheckSpec]):
        monthly_partition_negative_percent (Union[Unset, ColumnNegativePercentCheckSpec]):
        monthly_partition_non_negative_count (Union[Unset, ColumnNonNegativeCountCheckSpec]):
        monthly_partition_non_negative_percent (Union[Unset, ColumnNonNegativePercentCheckSpec]):
        monthly_partition_expected_numbers_in_use_count (Union[Unset, ColumnExpectedNumbersInUseCountCheckSpec]):
        monthly_partition_number_value_in_set_percent (Union[Unset, ColumnNumberValueInSetPercentCheckSpec]):
        monthly_partition_values_in_range_numeric_percent (Union[Unset, ColumnValuesInRangeNumericPercentCheckSpec]):
        monthly_partition_values_in_range_integers_percent (Union[Unset, ColumnValuesInRangeIntegersPercentCheckSpec]):
        monthly_partition_value_below_min_value_count (Union[Unset, ColumnValueBelowMinValueCountCheckSpec]):
        monthly_partition_value_below_min_value_percent (Union[Unset, ColumnValueBelowMinValuePercentCheckSpec]):
        monthly_partition_value_above_max_value_count (Union[Unset, ColumnValueAboveMaxValueCountCheckSpec]):
        monthly_partition_value_above_max_value_percent (Union[Unset, ColumnValueAboveMaxValuePercentCheckSpec]):
        monthly_partition_max_in_range (Union[Unset, ColumnMaxInRangeCheckSpec]):
        monthly_partition_min_in_range (Union[Unset, ColumnMinInRangeCheckSpec]):
        monthly_partition_mean_in_range (Union[Unset, ColumnMeanInRangeCheckSpec]):
        monthly_partition_percentile_in_range (Union[Unset, ColumnPercentileInRangeCheckSpec]):
        monthly_partition_median_in_range (Union[Unset, ColumnMedianInRangeCheckSpec]):
        monthly_partition_percentile_10_in_range (Union[Unset, ColumnPercentile10InRangeCheckSpec]):
        monthly_partition_percentile_25_in_range (Union[Unset, ColumnPercentile25InRangeCheckSpec]):
        monthly_partition_percentile_75_in_range (Union[Unset, ColumnPercentile75InRangeCheckSpec]):
        monthly_partition_percentile_90_in_range (Union[Unset, ColumnPercentile90InRangeCheckSpec]):
        monthly_partition_sample_stddev_in_range (Union[Unset, ColumnSampleStddevInRangeCheckSpec]):
        monthly_partition_population_stddev_in_range (Union[Unset, ColumnPopulationStddevInRangeCheckSpec]):
        monthly_partition_sample_variance_in_range (Union[Unset, ColumnSampleVarianceInRangeCheckSpec]):
        monthly_partition_population_variance_in_range (Union[Unset, ColumnPopulationVarianceInRangeCheckSpec]):
        monthly_partition_sum_in_range (Union[Unset, ColumnSumInRangeCheckSpec]):
        monthly_partition_invalid_latitude_count (Union[Unset, ColumnInvalidLatitudeCountCheckSpec]):
        monthly_partition_valid_latitude_percent (Union[Unset, ColumnValidLatitudePercentCheckSpec]):
        monthly_partition_invalid_longitude_count (Union[Unset, ColumnInvalidLongitudeCountCheckSpec]):
        monthly_partition_valid_longitude_percent (Union[Unset, ColumnValidLongitudePercentCheckSpec]):
    """

    monthly_partition_negative_count: Union[
        Unset, "ColumnNegativeCountCheckSpec"
    ] = UNSET
    monthly_partition_negative_percent: Union[
        Unset, "ColumnNegativePercentCheckSpec"
    ] = UNSET
    monthly_partition_non_negative_count: Union[
        Unset, "ColumnNonNegativeCountCheckSpec"
    ] = UNSET
    monthly_partition_non_negative_percent: Union[
        Unset, "ColumnNonNegativePercentCheckSpec"
    ] = UNSET
    monthly_partition_expected_numbers_in_use_count: Union[
        Unset, "ColumnExpectedNumbersInUseCountCheckSpec"
    ] = UNSET
    monthly_partition_number_value_in_set_percent: Union[
        Unset, "ColumnNumberValueInSetPercentCheckSpec"
    ] = UNSET
    monthly_partition_values_in_range_numeric_percent: Union[
        Unset, "ColumnValuesInRangeNumericPercentCheckSpec"
    ] = UNSET
    monthly_partition_values_in_range_integers_percent: Union[
        Unset, "ColumnValuesInRangeIntegersPercentCheckSpec"
    ] = UNSET
    monthly_partition_value_below_min_value_count: Union[
        Unset, "ColumnValueBelowMinValueCountCheckSpec"
    ] = UNSET
    monthly_partition_value_below_min_value_percent: Union[
        Unset, "ColumnValueBelowMinValuePercentCheckSpec"
    ] = UNSET
    monthly_partition_value_above_max_value_count: Union[
        Unset, "ColumnValueAboveMaxValueCountCheckSpec"
    ] = UNSET
    monthly_partition_value_above_max_value_percent: Union[
        Unset, "ColumnValueAboveMaxValuePercentCheckSpec"
    ] = UNSET
    monthly_partition_max_in_range: Union[Unset, "ColumnMaxInRangeCheckSpec"] = UNSET
    monthly_partition_min_in_range: Union[Unset, "ColumnMinInRangeCheckSpec"] = UNSET
    monthly_partition_mean_in_range: Union[Unset, "ColumnMeanInRangeCheckSpec"] = UNSET
    monthly_partition_percentile_in_range: Union[
        Unset, "ColumnPercentileInRangeCheckSpec"
    ] = UNSET
    monthly_partition_median_in_range: Union[
        Unset, "ColumnMedianInRangeCheckSpec"
    ] = UNSET
    monthly_partition_percentile_10_in_range: Union[
        Unset, "ColumnPercentile10InRangeCheckSpec"
    ] = UNSET
    monthly_partition_percentile_25_in_range: Union[
        Unset, "ColumnPercentile25InRangeCheckSpec"
    ] = UNSET
    monthly_partition_percentile_75_in_range: Union[
        Unset, "ColumnPercentile75InRangeCheckSpec"
    ] = UNSET
    monthly_partition_percentile_90_in_range: Union[
        Unset, "ColumnPercentile90InRangeCheckSpec"
    ] = UNSET
    monthly_partition_sample_stddev_in_range: Union[
        Unset, "ColumnSampleStddevInRangeCheckSpec"
    ] = UNSET
    monthly_partition_population_stddev_in_range: Union[
        Unset, "ColumnPopulationStddevInRangeCheckSpec"
    ] = UNSET
    monthly_partition_sample_variance_in_range: Union[
        Unset, "ColumnSampleVarianceInRangeCheckSpec"
    ] = UNSET
    monthly_partition_population_variance_in_range: Union[
        Unset, "ColumnPopulationVarianceInRangeCheckSpec"
    ] = UNSET
    monthly_partition_sum_in_range: Union[Unset, "ColumnSumInRangeCheckSpec"] = UNSET
    monthly_partition_invalid_latitude_count: Union[
        Unset, "ColumnInvalidLatitudeCountCheckSpec"
    ] = UNSET
    monthly_partition_valid_latitude_percent: Union[
        Unset, "ColumnValidLatitudePercentCheckSpec"
    ] = UNSET
    monthly_partition_invalid_longitude_count: Union[
        Unset, "ColumnInvalidLongitudeCountCheckSpec"
    ] = UNSET
    monthly_partition_valid_longitude_percent: Union[
        Unset, "ColumnValidLongitudePercentCheckSpec"
    ] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        monthly_partition_negative_count: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.monthly_partition_negative_count, Unset):
            monthly_partition_negative_count = (
                self.monthly_partition_negative_count.to_dict()
            )

        monthly_partition_negative_percent: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.monthly_partition_negative_percent, Unset):
            monthly_partition_negative_percent = (
                self.monthly_partition_negative_percent.to_dict()
            )

        monthly_partition_non_negative_count: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.monthly_partition_non_negative_count, Unset):
            monthly_partition_non_negative_count = (
                self.monthly_partition_non_negative_count.to_dict()
            )

        monthly_partition_non_negative_percent: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.monthly_partition_non_negative_percent, Unset):
            monthly_partition_non_negative_percent = (
                self.monthly_partition_non_negative_percent.to_dict()
            )

        monthly_partition_expected_numbers_in_use_count: Union[
            Unset, Dict[str, Any]
        ] = UNSET
        if not isinstance(self.monthly_partition_expected_numbers_in_use_count, Unset):
            monthly_partition_expected_numbers_in_use_count = (
                self.monthly_partition_expected_numbers_in_use_count.to_dict()
            )

        monthly_partition_number_value_in_set_percent: Union[
            Unset, Dict[str, Any]
        ] = UNSET
        if not isinstance(self.monthly_partition_number_value_in_set_percent, Unset):
            monthly_partition_number_value_in_set_percent = (
                self.monthly_partition_number_value_in_set_percent.to_dict()
            )

        monthly_partition_values_in_range_numeric_percent: Union[
            Unset, Dict[str, Any]
        ] = UNSET
        if not isinstance(
            self.monthly_partition_values_in_range_numeric_percent, Unset
        ):
            monthly_partition_values_in_range_numeric_percent = (
                self.monthly_partition_values_in_range_numeric_percent.to_dict()
            )

        monthly_partition_values_in_range_integers_percent: Union[
            Unset, Dict[str, Any]
        ] = UNSET
        if not isinstance(
            self.monthly_partition_values_in_range_integers_percent, Unset
        ):
            monthly_partition_values_in_range_integers_percent = (
                self.monthly_partition_values_in_range_integers_percent.to_dict()
            )

        monthly_partition_value_below_min_value_count: Union[
            Unset, Dict[str, Any]
        ] = UNSET
        if not isinstance(self.monthly_partition_value_below_min_value_count, Unset):
            monthly_partition_value_below_min_value_count = (
                self.monthly_partition_value_below_min_value_count.to_dict()
            )

        monthly_partition_value_below_min_value_percent: Union[
            Unset, Dict[str, Any]
        ] = UNSET
        if not isinstance(self.monthly_partition_value_below_min_value_percent, Unset):
            monthly_partition_value_below_min_value_percent = (
                self.monthly_partition_value_below_min_value_percent.to_dict()
            )

        monthly_partition_value_above_max_value_count: Union[
            Unset, Dict[str, Any]
        ] = UNSET
        if not isinstance(self.monthly_partition_value_above_max_value_count, Unset):
            monthly_partition_value_above_max_value_count = (
                self.monthly_partition_value_above_max_value_count.to_dict()
            )

        monthly_partition_value_above_max_value_percent: Union[
            Unset, Dict[str, Any]
        ] = UNSET
        if not isinstance(self.monthly_partition_value_above_max_value_percent, Unset):
            monthly_partition_value_above_max_value_percent = (
                self.monthly_partition_value_above_max_value_percent.to_dict()
            )

        monthly_partition_max_in_range: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.monthly_partition_max_in_range, Unset):
            monthly_partition_max_in_range = (
                self.monthly_partition_max_in_range.to_dict()
            )

        monthly_partition_min_in_range: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.monthly_partition_min_in_range, Unset):
            monthly_partition_min_in_range = (
                self.monthly_partition_min_in_range.to_dict()
            )

        monthly_partition_mean_in_range: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.monthly_partition_mean_in_range, Unset):
            monthly_partition_mean_in_range = (
                self.monthly_partition_mean_in_range.to_dict()
            )

        monthly_partition_percentile_in_range: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.monthly_partition_percentile_in_range, Unset):
            monthly_partition_percentile_in_range = (
                self.monthly_partition_percentile_in_range.to_dict()
            )

        monthly_partition_median_in_range: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.monthly_partition_median_in_range, Unset):
            monthly_partition_median_in_range = (
                self.monthly_partition_median_in_range.to_dict()
            )

        monthly_partition_percentile_10_in_range: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.monthly_partition_percentile_10_in_range, Unset):
            monthly_partition_percentile_10_in_range = (
                self.monthly_partition_percentile_10_in_range.to_dict()
            )

        monthly_partition_percentile_25_in_range: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.monthly_partition_percentile_25_in_range, Unset):
            monthly_partition_percentile_25_in_range = (
                self.monthly_partition_percentile_25_in_range.to_dict()
            )

        monthly_partition_percentile_75_in_range: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.monthly_partition_percentile_75_in_range, Unset):
            monthly_partition_percentile_75_in_range = (
                self.monthly_partition_percentile_75_in_range.to_dict()
            )

        monthly_partition_percentile_90_in_range: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.monthly_partition_percentile_90_in_range, Unset):
            monthly_partition_percentile_90_in_range = (
                self.monthly_partition_percentile_90_in_range.to_dict()
            )

        monthly_partition_sample_stddev_in_range: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.monthly_partition_sample_stddev_in_range, Unset):
            monthly_partition_sample_stddev_in_range = (
                self.monthly_partition_sample_stddev_in_range.to_dict()
            )

        monthly_partition_population_stddev_in_range: Union[
            Unset, Dict[str, Any]
        ] = UNSET
        if not isinstance(self.monthly_partition_population_stddev_in_range, Unset):
            monthly_partition_population_stddev_in_range = (
                self.monthly_partition_population_stddev_in_range.to_dict()
            )

        monthly_partition_sample_variance_in_range: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.monthly_partition_sample_variance_in_range, Unset):
            monthly_partition_sample_variance_in_range = (
                self.monthly_partition_sample_variance_in_range.to_dict()
            )

        monthly_partition_population_variance_in_range: Union[
            Unset, Dict[str, Any]
        ] = UNSET
        if not isinstance(self.monthly_partition_population_variance_in_range, Unset):
            monthly_partition_population_variance_in_range = (
                self.monthly_partition_population_variance_in_range.to_dict()
            )

        monthly_partition_sum_in_range: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.monthly_partition_sum_in_range, Unset):
            monthly_partition_sum_in_range = (
                self.monthly_partition_sum_in_range.to_dict()
            )

        monthly_partition_invalid_latitude_count: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.monthly_partition_invalid_latitude_count, Unset):
            monthly_partition_invalid_latitude_count = (
                self.monthly_partition_invalid_latitude_count.to_dict()
            )

        monthly_partition_valid_latitude_percent: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.monthly_partition_valid_latitude_percent, Unset):
            monthly_partition_valid_latitude_percent = (
                self.monthly_partition_valid_latitude_percent.to_dict()
            )

        monthly_partition_invalid_longitude_count: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.monthly_partition_invalid_longitude_count, Unset):
            monthly_partition_invalid_longitude_count = (
                self.monthly_partition_invalid_longitude_count.to_dict()
            )

        monthly_partition_valid_longitude_percent: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.monthly_partition_valid_longitude_percent, Unset):
            monthly_partition_valid_longitude_percent = (
                self.monthly_partition_valid_longitude_percent.to_dict()
            )

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if monthly_partition_negative_count is not UNSET:
            field_dict[
                "monthly_partition_negative_count"
            ] = monthly_partition_negative_count
        if monthly_partition_negative_percent is not UNSET:
            field_dict[
                "monthly_partition_negative_percent"
            ] = monthly_partition_negative_percent
        if monthly_partition_non_negative_count is not UNSET:
            field_dict[
                "monthly_partition_non_negative_count"
            ] = monthly_partition_non_negative_count
        if monthly_partition_non_negative_percent is not UNSET:
            field_dict[
                "monthly_partition_non_negative_percent"
            ] = monthly_partition_non_negative_percent
        if monthly_partition_expected_numbers_in_use_count is not UNSET:
            field_dict[
                "monthly_partition_expected_numbers_in_use_count"
            ] = monthly_partition_expected_numbers_in_use_count
        if monthly_partition_number_value_in_set_percent is not UNSET:
            field_dict[
                "monthly_partition_number_value_in_set_percent"
            ] = monthly_partition_number_value_in_set_percent
        if monthly_partition_values_in_range_numeric_percent is not UNSET:
            field_dict[
                "monthly_partition_values_in_range_numeric_percent"
            ] = monthly_partition_values_in_range_numeric_percent
        if monthly_partition_values_in_range_integers_percent is not UNSET:
            field_dict[
                "monthly_partition_values_in_range_integers_percent"
            ] = monthly_partition_values_in_range_integers_percent
        if monthly_partition_value_below_min_value_count is not UNSET:
            field_dict[
                "monthly_partition_value_below_min_value_count"
            ] = monthly_partition_value_below_min_value_count
        if monthly_partition_value_below_min_value_percent is not UNSET:
            field_dict[
                "monthly_partition_value_below_min_value_percent"
            ] = monthly_partition_value_below_min_value_percent
        if monthly_partition_value_above_max_value_count is not UNSET:
            field_dict[
                "monthly_partition_value_above_max_value_count"
            ] = monthly_partition_value_above_max_value_count
        if monthly_partition_value_above_max_value_percent is not UNSET:
            field_dict[
                "monthly_partition_value_above_max_value_percent"
            ] = monthly_partition_value_above_max_value_percent
        if monthly_partition_max_in_range is not UNSET:
            field_dict[
                "monthly_partition_max_in_range"
            ] = monthly_partition_max_in_range
        if monthly_partition_min_in_range is not UNSET:
            field_dict[
                "monthly_partition_min_in_range"
            ] = monthly_partition_min_in_range
        if monthly_partition_mean_in_range is not UNSET:
            field_dict[
                "monthly_partition_mean_in_range"
            ] = monthly_partition_mean_in_range
        if monthly_partition_percentile_in_range is not UNSET:
            field_dict[
                "monthly_partition_percentile_in_range"
            ] = monthly_partition_percentile_in_range
        if monthly_partition_median_in_range is not UNSET:
            field_dict[
                "monthly_partition_median_in_range"
            ] = monthly_partition_median_in_range
        if monthly_partition_percentile_10_in_range is not UNSET:
            field_dict[
                "monthly_partition_percentile_10_in_range"
            ] = monthly_partition_percentile_10_in_range
        if monthly_partition_percentile_25_in_range is not UNSET:
            field_dict[
                "monthly_partition_percentile_25_in_range"
            ] = monthly_partition_percentile_25_in_range
        if monthly_partition_percentile_75_in_range is not UNSET:
            field_dict[
                "monthly_partition_percentile_75_in_range"
            ] = monthly_partition_percentile_75_in_range
        if monthly_partition_percentile_90_in_range is not UNSET:
            field_dict[
                "monthly_partition_percentile_90_in_range"
            ] = monthly_partition_percentile_90_in_range
        if monthly_partition_sample_stddev_in_range is not UNSET:
            field_dict[
                "monthly_partition_sample_stddev_in_range"
            ] = monthly_partition_sample_stddev_in_range
        if monthly_partition_population_stddev_in_range is not UNSET:
            field_dict[
                "monthly_partition_population_stddev_in_range"
            ] = monthly_partition_population_stddev_in_range
        if monthly_partition_sample_variance_in_range is not UNSET:
            field_dict[
                "monthly_partition_sample_variance_in_range"
            ] = monthly_partition_sample_variance_in_range
        if monthly_partition_population_variance_in_range is not UNSET:
            field_dict[
                "monthly_partition_population_variance_in_range"
            ] = monthly_partition_population_variance_in_range
        if monthly_partition_sum_in_range is not UNSET:
            field_dict[
                "monthly_partition_sum_in_range"
            ] = monthly_partition_sum_in_range
        if monthly_partition_invalid_latitude_count is not UNSET:
            field_dict[
                "monthly_partition_invalid_latitude_count"
            ] = monthly_partition_invalid_latitude_count
        if monthly_partition_valid_latitude_percent is not UNSET:
            field_dict[
                "monthly_partition_valid_latitude_percent"
            ] = monthly_partition_valid_latitude_percent
        if monthly_partition_invalid_longitude_count is not UNSET:
            field_dict[
                "monthly_partition_invalid_longitude_count"
            ] = monthly_partition_invalid_longitude_count
        if monthly_partition_valid_longitude_percent is not UNSET:
            field_dict[
                "monthly_partition_valid_longitude_percent"
            ] = monthly_partition_valid_longitude_percent

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.column_expected_numbers_in_use_count_check_spec import (
            ColumnExpectedNumbersInUseCountCheckSpec,
        )
        from ..models.column_invalid_latitude_count_check_spec import (
            ColumnInvalidLatitudeCountCheckSpec,
        )
        from ..models.column_invalid_longitude_count_check_spec import (
            ColumnInvalidLongitudeCountCheckSpec,
        )
        from ..models.column_max_in_range_check_spec import ColumnMaxInRangeCheckSpec
        from ..models.column_mean_in_range_check_spec import ColumnMeanInRangeCheckSpec
        from ..models.column_median_in_range_check_spec import (
            ColumnMedianInRangeCheckSpec,
        )
        from ..models.column_min_in_range_check_spec import ColumnMinInRangeCheckSpec
        from ..models.column_negative_count_check_spec import (
            ColumnNegativeCountCheckSpec,
        )
        from ..models.column_negative_percent_check_spec import (
            ColumnNegativePercentCheckSpec,
        )
        from ..models.column_non_negative_count_check_spec import (
            ColumnNonNegativeCountCheckSpec,
        )
        from ..models.column_non_negative_percent_check_spec import (
            ColumnNonNegativePercentCheckSpec,
        )
        from ..models.column_number_value_in_set_percent_check_spec import (
            ColumnNumberValueInSetPercentCheckSpec,
        )
        from ..models.column_percentile_10_in_range_check_spec import (
            ColumnPercentile10InRangeCheckSpec,
        )
        from ..models.column_percentile_25_in_range_check_spec import (
            ColumnPercentile25InRangeCheckSpec,
        )
        from ..models.column_percentile_75_in_range_check_spec import (
            ColumnPercentile75InRangeCheckSpec,
        )
        from ..models.column_percentile_90_in_range_check_spec import (
            ColumnPercentile90InRangeCheckSpec,
        )
        from ..models.column_percentile_in_range_check_spec import (
            ColumnPercentileInRangeCheckSpec,
        )
        from ..models.column_population_stddev_in_range_check_spec import (
            ColumnPopulationStddevInRangeCheckSpec,
        )
        from ..models.column_population_variance_in_range_check_spec import (
            ColumnPopulationVarianceInRangeCheckSpec,
        )
        from ..models.column_sample_stddev_in_range_check_spec import (
            ColumnSampleStddevInRangeCheckSpec,
        )
        from ..models.column_sample_variance_in_range_check_spec import (
            ColumnSampleVarianceInRangeCheckSpec,
        )
        from ..models.column_sum_in_range_check_spec import ColumnSumInRangeCheckSpec
        from ..models.column_valid_latitude_percent_check_spec import (
            ColumnValidLatitudePercentCheckSpec,
        )
        from ..models.column_valid_longitude_percent_check_spec import (
            ColumnValidLongitudePercentCheckSpec,
        )
        from ..models.column_value_above_max_value_count_check_spec import (
            ColumnValueAboveMaxValueCountCheckSpec,
        )
        from ..models.column_value_above_max_value_percent_check_spec import (
            ColumnValueAboveMaxValuePercentCheckSpec,
        )
        from ..models.column_value_below_min_value_count_check_spec import (
            ColumnValueBelowMinValueCountCheckSpec,
        )
        from ..models.column_value_below_min_value_percent_check_spec import (
            ColumnValueBelowMinValuePercentCheckSpec,
        )
        from ..models.column_values_in_range_integers_percent_check_spec import (
            ColumnValuesInRangeIntegersPercentCheckSpec,
        )
        from ..models.column_values_in_range_numeric_percent_check_spec import (
            ColumnValuesInRangeNumericPercentCheckSpec,
        )

        d = src_dict.copy()
        _monthly_partition_negative_count = d.pop(
            "monthly_partition_negative_count", UNSET
        )
        monthly_partition_negative_count: Union[Unset, ColumnNegativeCountCheckSpec]
        if isinstance(_monthly_partition_negative_count, Unset):
            monthly_partition_negative_count = UNSET
        else:
            monthly_partition_negative_count = ColumnNegativeCountCheckSpec.from_dict(
                _monthly_partition_negative_count
            )

        _monthly_partition_negative_percent = d.pop(
            "monthly_partition_negative_percent", UNSET
        )
        monthly_partition_negative_percent: Union[Unset, ColumnNegativePercentCheckSpec]
        if isinstance(_monthly_partition_negative_percent, Unset):
            monthly_partition_negative_percent = UNSET
        else:
            monthly_partition_negative_percent = (
                ColumnNegativePercentCheckSpec.from_dict(
                    _monthly_partition_negative_percent
                )
            )

        _monthly_partition_non_negative_count = d.pop(
            "monthly_partition_non_negative_count", UNSET
        )
        monthly_partition_non_negative_count: Union[
            Unset, ColumnNonNegativeCountCheckSpec
        ]
        if isinstance(_monthly_partition_non_negative_count, Unset):
            monthly_partition_non_negative_count = UNSET
        else:
            monthly_partition_non_negative_count = (
                ColumnNonNegativeCountCheckSpec.from_dict(
                    _monthly_partition_non_negative_count
                )
            )

        _monthly_partition_non_negative_percent = d.pop(
            "monthly_partition_non_negative_percent", UNSET
        )
        monthly_partition_non_negative_percent: Union[
            Unset, ColumnNonNegativePercentCheckSpec
        ]
        if isinstance(_monthly_partition_non_negative_percent, Unset):
            monthly_partition_non_negative_percent = UNSET
        else:
            monthly_partition_non_negative_percent = (
                ColumnNonNegativePercentCheckSpec.from_dict(
                    _monthly_partition_non_negative_percent
                )
            )

        _monthly_partition_expected_numbers_in_use_count = d.pop(
            "monthly_partition_expected_numbers_in_use_count", UNSET
        )
        monthly_partition_expected_numbers_in_use_count: Union[
            Unset, ColumnExpectedNumbersInUseCountCheckSpec
        ]
        if isinstance(_monthly_partition_expected_numbers_in_use_count, Unset):
            monthly_partition_expected_numbers_in_use_count = UNSET
        else:
            monthly_partition_expected_numbers_in_use_count = (
                ColumnExpectedNumbersInUseCountCheckSpec.from_dict(
                    _monthly_partition_expected_numbers_in_use_count
                )
            )

        _monthly_partition_number_value_in_set_percent = d.pop(
            "monthly_partition_number_value_in_set_percent", UNSET
        )
        monthly_partition_number_value_in_set_percent: Union[
            Unset, ColumnNumberValueInSetPercentCheckSpec
        ]
        if isinstance(_monthly_partition_number_value_in_set_percent, Unset):
            monthly_partition_number_value_in_set_percent = UNSET
        else:
            monthly_partition_number_value_in_set_percent = (
                ColumnNumberValueInSetPercentCheckSpec.from_dict(
                    _monthly_partition_number_value_in_set_percent
                )
            )

        _monthly_partition_values_in_range_numeric_percent = d.pop(
            "monthly_partition_values_in_range_numeric_percent", UNSET
        )
        monthly_partition_values_in_range_numeric_percent: Union[
            Unset, ColumnValuesInRangeNumericPercentCheckSpec
        ]
        if isinstance(_monthly_partition_values_in_range_numeric_percent, Unset):
            monthly_partition_values_in_range_numeric_percent = UNSET
        else:
            monthly_partition_values_in_range_numeric_percent = (
                ColumnValuesInRangeNumericPercentCheckSpec.from_dict(
                    _monthly_partition_values_in_range_numeric_percent
                )
            )

        _monthly_partition_values_in_range_integers_percent = d.pop(
            "monthly_partition_values_in_range_integers_percent", UNSET
        )
        monthly_partition_values_in_range_integers_percent: Union[
            Unset, ColumnValuesInRangeIntegersPercentCheckSpec
        ]
        if isinstance(_monthly_partition_values_in_range_integers_percent, Unset):
            monthly_partition_values_in_range_integers_percent = UNSET
        else:
            monthly_partition_values_in_range_integers_percent = (
                ColumnValuesInRangeIntegersPercentCheckSpec.from_dict(
                    _monthly_partition_values_in_range_integers_percent
                )
            )

        _monthly_partition_value_below_min_value_count = d.pop(
            "monthly_partition_value_below_min_value_count", UNSET
        )
        monthly_partition_value_below_min_value_count: Union[
            Unset, ColumnValueBelowMinValueCountCheckSpec
        ]
        if isinstance(_monthly_partition_value_below_min_value_count, Unset):
            monthly_partition_value_below_min_value_count = UNSET
        else:
            monthly_partition_value_below_min_value_count = (
                ColumnValueBelowMinValueCountCheckSpec.from_dict(
                    _monthly_partition_value_below_min_value_count
                )
            )

        _monthly_partition_value_below_min_value_percent = d.pop(
            "monthly_partition_value_below_min_value_percent", UNSET
        )
        monthly_partition_value_below_min_value_percent: Union[
            Unset, ColumnValueBelowMinValuePercentCheckSpec
        ]
        if isinstance(_monthly_partition_value_below_min_value_percent, Unset):
            monthly_partition_value_below_min_value_percent = UNSET
        else:
            monthly_partition_value_below_min_value_percent = (
                ColumnValueBelowMinValuePercentCheckSpec.from_dict(
                    _monthly_partition_value_below_min_value_percent
                )
            )

        _monthly_partition_value_above_max_value_count = d.pop(
            "monthly_partition_value_above_max_value_count", UNSET
        )
        monthly_partition_value_above_max_value_count: Union[
            Unset, ColumnValueAboveMaxValueCountCheckSpec
        ]
        if isinstance(_monthly_partition_value_above_max_value_count, Unset):
            monthly_partition_value_above_max_value_count = UNSET
        else:
            monthly_partition_value_above_max_value_count = (
                ColumnValueAboveMaxValueCountCheckSpec.from_dict(
                    _monthly_partition_value_above_max_value_count
                )
            )

        _monthly_partition_value_above_max_value_percent = d.pop(
            "monthly_partition_value_above_max_value_percent", UNSET
        )
        monthly_partition_value_above_max_value_percent: Union[
            Unset, ColumnValueAboveMaxValuePercentCheckSpec
        ]
        if isinstance(_monthly_partition_value_above_max_value_percent, Unset):
            monthly_partition_value_above_max_value_percent = UNSET
        else:
            monthly_partition_value_above_max_value_percent = (
                ColumnValueAboveMaxValuePercentCheckSpec.from_dict(
                    _monthly_partition_value_above_max_value_percent
                )
            )

        _monthly_partition_max_in_range = d.pop("monthly_partition_max_in_range", UNSET)
        monthly_partition_max_in_range: Union[Unset, ColumnMaxInRangeCheckSpec]
        if isinstance(_monthly_partition_max_in_range, Unset):
            monthly_partition_max_in_range = UNSET
        else:
            monthly_partition_max_in_range = ColumnMaxInRangeCheckSpec.from_dict(
                _monthly_partition_max_in_range
            )

        _monthly_partition_min_in_range = d.pop("monthly_partition_min_in_range", UNSET)
        monthly_partition_min_in_range: Union[Unset, ColumnMinInRangeCheckSpec]
        if isinstance(_monthly_partition_min_in_range, Unset):
            monthly_partition_min_in_range = UNSET
        else:
            monthly_partition_min_in_range = ColumnMinInRangeCheckSpec.from_dict(
                _monthly_partition_min_in_range
            )

        _monthly_partition_mean_in_range = d.pop(
            "monthly_partition_mean_in_range", UNSET
        )
        monthly_partition_mean_in_range: Union[Unset, ColumnMeanInRangeCheckSpec]
        if isinstance(_monthly_partition_mean_in_range, Unset):
            monthly_partition_mean_in_range = UNSET
        else:
            monthly_partition_mean_in_range = ColumnMeanInRangeCheckSpec.from_dict(
                _monthly_partition_mean_in_range
            )

        _monthly_partition_percentile_in_range = d.pop(
            "monthly_partition_percentile_in_range", UNSET
        )
        monthly_partition_percentile_in_range: Union[
            Unset, ColumnPercentileInRangeCheckSpec
        ]
        if isinstance(_monthly_partition_percentile_in_range, Unset):
            monthly_partition_percentile_in_range = UNSET
        else:
            monthly_partition_percentile_in_range = (
                ColumnPercentileInRangeCheckSpec.from_dict(
                    _monthly_partition_percentile_in_range
                )
            )

        _monthly_partition_median_in_range = d.pop(
            "monthly_partition_median_in_range", UNSET
        )
        monthly_partition_median_in_range: Union[Unset, ColumnMedianInRangeCheckSpec]
        if isinstance(_monthly_partition_median_in_range, Unset):
            monthly_partition_median_in_range = UNSET
        else:
            monthly_partition_median_in_range = ColumnMedianInRangeCheckSpec.from_dict(
                _monthly_partition_median_in_range
            )

        _monthly_partition_percentile_10_in_range = d.pop(
            "monthly_partition_percentile_10_in_range", UNSET
        )
        monthly_partition_percentile_10_in_range: Union[
            Unset, ColumnPercentile10InRangeCheckSpec
        ]
        if isinstance(_monthly_partition_percentile_10_in_range, Unset):
            monthly_partition_percentile_10_in_range = UNSET
        else:
            monthly_partition_percentile_10_in_range = (
                ColumnPercentile10InRangeCheckSpec.from_dict(
                    _monthly_partition_percentile_10_in_range
                )
            )

        _monthly_partition_percentile_25_in_range = d.pop(
            "monthly_partition_percentile_25_in_range", UNSET
        )
        monthly_partition_percentile_25_in_range: Union[
            Unset, ColumnPercentile25InRangeCheckSpec
        ]
        if isinstance(_monthly_partition_percentile_25_in_range, Unset):
            monthly_partition_percentile_25_in_range = UNSET
        else:
            monthly_partition_percentile_25_in_range = (
                ColumnPercentile25InRangeCheckSpec.from_dict(
                    _monthly_partition_percentile_25_in_range
                )
            )

        _monthly_partition_percentile_75_in_range = d.pop(
            "monthly_partition_percentile_75_in_range", UNSET
        )
        monthly_partition_percentile_75_in_range: Union[
            Unset, ColumnPercentile75InRangeCheckSpec
        ]
        if isinstance(_monthly_partition_percentile_75_in_range, Unset):
            monthly_partition_percentile_75_in_range = UNSET
        else:
            monthly_partition_percentile_75_in_range = (
                ColumnPercentile75InRangeCheckSpec.from_dict(
                    _monthly_partition_percentile_75_in_range
                )
            )

        _monthly_partition_percentile_90_in_range = d.pop(
            "monthly_partition_percentile_90_in_range", UNSET
        )
        monthly_partition_percentile_90_in_range: Union[
            Unset, ColumnPercentile90InRangeCheckSpec
        ]
        if isinstance(_monthly_partition_percentile_90_in_range, Unset):
            monthly_partition_percentile_90_in_range = UNSET
        else:
            monthly_partition_percentile_90_in_range = (
                ColumnPercentile90InRangeCheckSpec.from_dict(
                    _monthly_partition_percentile_90_in_range
                )
            )

        _monthly_partition_sample_stddev_in_range = d.pop(
            "monthly_partition_sample_stddev_in_range", UNSET
        )
        monthly_partition_sample_stddev_in_range: Union[
            Unset, ColumnSampleStddevInRangeCheckSpec
        ]
        if isinstance(_monthly_partition_sample_stddev_in_range, Unset):
            monthly_partition_sample_stddev_in_range = UNSET
        else:
            monthly_partition_sample_stddev_in_range = (
                ColumnSampleStddevInRangeCheckSpec.from_dict(
                    _monthly_partition_sample_stddev_in_range
                )
            )

        _monthly_partition_population_stddev_in_range = d.pop(
            "monthly_partition_population_stddev_in_range", UNSET
        )
        monthly_partition_population_stddev_in_range: Union[
            Unset, ColumnPopulationStddevInRangeCheckSpec
        ]
        if isinstance(_monthly_partition_population_stddev_in_range, Unset):
            monthly_partition_population_stddev_in_range = UNSET
        else:
            monthly_partition_population_stddev_in_range = (
                ColumnPopulationStddevInRangeCheckSpec.from_dict(
                    _monthly_partition_population_stddev_in_range
                )
            )

        _monthly_partition_sample_variance_in_range = d.pop(
            "monthly_partition_sample_variance_in_range", UNSET
        )
        monthly_partition_sample_variance_in_range: Union[
            Unset, ColumnSampleVarianceInRangeCheckSpec
        ]
        if isinstance(_monthly_partition_sample_variance_in_range, Unset):
            monthly_partition_sample_variance_in_range = UNSET
        else:
            monthly_partition_sample_variance_in_range = (
                ColumnSampleVarianceInRangeCheckSpec.from_dict(
                    _monthly_partition_sample_variance_in_range
                )
            )

        _monthly_partition_population_variance_in_range = d.pop(
            "monthly_partition_population_variance_in_range", UNSET
        )
        monthly_partition_population_variance_in_range: Union[
            Unset, ColumnPopulationVarianceInRangeCheckSpec
        ]
        if isinstance(_monthly_partition_population_variance_in_range, Unset):
            monthly_partition_population_variance_in_range = UNSET
        else:
            monthly_partition_population_variance_in_range = (
                ColumnPopulationVarianceInRangeCheckSpec.from_dict(
                    _monthly_partition_population_variance_in_range
                )
            )

        _monthly_partition_sum_in_range = d.pop("monthly_partition_sum_in_range", UNSET)
        monthly_partition_sum_in_range: Union[Unset, ColumnSumInRangeCheckSpec]
        if isinstance(_monthly_partition_sum_in_range, Unset):
            monthly_partition_sum_in_range = UNSET
        else:
            monthly_partition_sum_in_range = ColumnSumInRangeCheckSpec.from_dict(
                _monthly_partition_sum_in_range
            )

        _monthly_partition_invalid_latitude_count = d.pop(
            "monthly_partition_invalid_latitude_count", UNSET
        )
        monthly_partition_invalid_latitude_count: Union[
            Unset, ColumnInvalidLatitudeCountCheckSpec
        ]
        if isinstance(_monthly_partition_invalid_latitude_count, Unset):
            monthly_partition_invalid_latitude_count = UNSET
        else:
            monthly_partition_invalid_latitude_count = (
                ColumnInvalidLatitudeCountCheckSpec.from_dict(
                    _monthly_partition_invalid_latitude_count
                )
            )

        _monthly_partition_valid_latitude_percent = d.pop(
            "monthly_partition_valid_latitude_percent", UNSET
        )
        monthly_partition_valid_latitude_percent: Union[
            Unset, ColumnValidLatitudePercentCheckSpec
        ]
        if isinstance(_monthly_partition_valid_latitude_percent, Unset):
            monthly_partition_valid_latitude_percent = UNSET
        else:
            monthly_partition_valid_latitude_percent = (
                ColumnValidLatitudePercentCheckSpec.from_dict(
                    _monthly_partition_valid_latitude_percent
                )
            )

        _monthly_partition_invalid_longitude_count = d.pop(
            "monthly_partition_invalid_longitude_count", UNSET
        )
        monthly_partition_invalid_longitude_count: Union[
            Unset, ColumnInvalidLongitudeCountCheckSpec
        ]
        if isinstance(_monthly_partition_invalid_longitude_count, Unset):
            monthly_partition_invalid_longitude_count = UNSET
        else:
            monthly_partition_invalid_longitude_count = (
                ColumnInvalidLongitudeCountCheckSpec.from_dict(
                    _monthly_partition_invalid_longitude_count
                )
            )

        _monthly_partition_valid_longitude_percent = d.pop(
            "monthly_partition_valid_longitude_percent", UNSET
        )
        monthly_partition_valid_longitude_percent: Union[
            Unset, ColumnValidLongitudePercentCheckSpec
        ]
        if isinstance(_monthly_partition_valid_longitude_percent, Unset):
            monthly_partition_valid_longitude_percent = UNSET
        else:
            monthly_partition_valid_longitude_percent = (
                ColumnValidLongitudePercentCheckSpec.from_dict(
                    _monthly_partition_valid_longitude_percent
                )
            )

        column_numeric_monthly_partitioned_checks_spec = cls(
            monthly_partition_negative_count=monthly_partition_negative_count,
            monthly_partition_negative_percent=monthly_partition_negative_percent,
            monthly_partition_non_negative_count=monthly_partition_non_negative_count,
            monthly_partition_non_negative_percent=monthly_partition_non_negative_percent,
            monthly_partition_expected_numbers_in_use_count=monthly_partition_expected_numbers_in_use_count,
            monthly_partition_number_value_in_set_percent=monthly_partition_number_value_in_set_percent,
            monthly_partition_values_in_range_numeric_percent=monthly_partition_values_in_range_numeric_percent,
            monthly_partition_values_in_range_integers_percent=monthly_partition_values_in_range_integers_percent,
            monthly_partition_value_below_min_value_count=monthly_partition_value_below_min_value_count,
            monthly_partition_value_below_min_value_percent=monthly_partition_value_below_min_value_percent,
            monthly_partition_value_above_max_value_count=monthly_partition_value_above_max_value_count,
            monthly_partition_value_above_max_value_percent=monthly_partition_value_above_max_value_percent,
            monthly_partition_max_in_range=monthly_partition_max_in_range,
            monthly_partition_min_in_range=monthly_partition_min_in_range,
            monthly_partition_mean_in_range=monthly_partition_mean_in_range,
            monthly_partition_percentile_in_range=monthly_partition_percentile_in_range,
            monthly_partition_median_in_range=monthly_partition_median_in_range,
            monthly_partition_percentile_10_in_range=monthly_partition_percentile_10_in_range,
            monthly_partition_percentile_25_in_range=monthly_partition_percentile_25_in_range,
            monthly_partition_percentile_75_in_range=monthly_partition_percentile_75_in_range,
            monthly_partition_percentile_90_in_range=monthly_partition_percentile_90_in_range,
            monthly_partition_sample_stddev_in_range=monthly_partition_sample_stddev_in_range,
            monthly_partition_population_stddev_in_range=monthly_partition_population_stddev_in_range,
            monthly_partition_sample_variance_in_range=monthly_partition_sample_variance_in_range,
            monthly_partition_population_variance_in_range=monthly_partition_population_variance_in_range,
            monthly_partition_sum_in_range=monthly_partition_sum_in_range,
            monthly_partition_invalid_latitude_count=monthly_partition_invalid_latitude_count,
            monthly_partition_valid_latitude_percent=monthly_partition_valid_latitude_percent,
            monthly_partition_invalid_longitude_count=monthly_partition_invalid_longitude_count,
            monthly_partition_valid_longitude_percent=monthly_partition_valid_longitude_percent,
        )

        column_numeric_monthly_partitioned_checks_spec.additional_properties = d
        return column_numeric_monthly_partitioned_checks_spec

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar

import attr

if TYPE_CHECKING:
    from ..models.table_comparison_configuration_spec import (
        TableComparisonConfigurationSpec,
    )


T = TypeVar("T", bound="TableSpecTableComparisons")


@attr.s(auto_attribs=True)
class TableSpecTableComparisons:
    """Dictionary of data comparison configurations. Data comparison configurations are used for cross data-source
    comparisons to compare this table (called the compared table) with other reference tables (the source of truth). The
    reference table's metadata must be imported into DQO, but the reference table could be located on a different data
    source. DQO will compare metrics calculated for groups of rows (using a GROUP BY clause). For each comparison, the
    user must specify a name of a data grouping. The number of data grouping dimensions on the parent table and the
    reference table defined in selected data grouping configurations must match. DQO will run the same data quality
    sensors on both the parent table (tested table) and the reference table (the source of truth), comparing the
    measures (sensor readouts) captured from both the tables.

    """

    additional_properties: Dict[str, "TableComparisonConfigurationSpec"] = attr.ib(
        init=False, factory=dict
    )

    def to_dict(self) -> Dict[str, Any]:
        pass

        field_dict: Dict[str, Any] = {}
        for prop_name, prop in self.additional_properties.items():
            field_dict[prop_name] = prop.to_dict()

        field_dict.update({})

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.table_comparison_configuration_spec import (
            TableComparisonConfigurationSpec,
        )

        d = src_dict.copy()
        table_spec_table_comparisons = cls()

        additional_properties = {}
        for prop_name, prop_dict in d.items():
            additional_property = TableComparisonConfigurationSpec.from_dict(prop_dict)

            additional_properties[prop_name] = additional_property

        table_spec_table_comparisons.additional_properties = additional_properties
        return table_spec_table_comparisons

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> "TableComparisonConfigurationSpec":
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: "TableComparisonConfigurationSpec") -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from enum import Enum


class ConnectionSpecProviderType(str, Enum):
    BIGQUERY = "bigquery"
    MYSQL = "mysql"
    ORACLE = "oracle"
    POSTGRESQL = "postgresql"
    REDSHIFT = "redshift"
    SNOWFLAKE = "snowflake"
    SQLSERVER = "sqlserver"

    def __str__(self) -> str:
        return str(self.value)



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union, cast

import attr

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.sensor_readout_detailed_single_model import (
        SensorReadoutDetailedSingleModel,
    )


T = TypeVar("T", bound="SensorReadoutsDetailedDataModel")


@attr.s(auto_attribs=True)
class SensorReadoutsDetailedDataModel:
    """
    Attributes:
        check_name (Union[Unset, str]): Check name.
        check_display_name (Union[Unset, str]): Check display name.
        check_type (Union[Unset, str]): Check type.
        check_hash (Union[Unset, int]): Check hash.
        check_category (Union[Unset, str]): Check category name.
        sensor_name (Union[Unset, str]): Sensor name.
        data_group_names (Union[Unset, List[str]]): Data groups list.
        data_group (Union[Unset, str]): Selected data group.
        single_sensor_readouts (Union[Unset, List['SensorReadoutDetailedSingleModel']]): Single sensor readouts
    """

    check_name: Union[Unset, str] = UNSET
    check_display_name: Union[Unset, str] = UNSET
    check_type: Union[Unset, str] = UNSET
    check_hash: Union[Unset, int] = UNSET
    check_category: Union[Unset, str] = UNSET
    sensor_name: Union[Unset, str] = UNSET
    data_group_names: Union[Unset, List[str]] = UNSET
    data_group: Union[Unset, str] = UNSET
    single_sensor_readouts: Union[
        Unset, List["SensorReadoutDetailedSingleModel"]
    ] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        check_name = self.check_name
        check_display_name = self.check_display_name
        check_type = self.check_type
        check_hash = self.check_hash
        check_category = self.check_category
        sensor_name = self.sensor_name
        data_group_names: Union[Unset, List[str]] = UNSET
        if not isinstance(self.data_group_names, Unset):
            data_group_names = self.data_group_names

        data_group = self.data_group
        single_sensor_readouts: Union[Unset, List[Dict[str, Any]]] = UNSET
        if not isinstance(self.single_sensor_readouts, Unset):
            single_sensor_readouts = []
            for single_sensor_readouts_item_data in self.single_sensor_readouts:
                single_sensor_readouts_item = single_sensor_readouts_item_data.to_dict()

                single_sensor_readouts.append(single_sensor_readouts_item)

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if check_name is not UNSET:
            field_dict["checkName"] = check_name
        if check_display_name is not UNSET:
            field_dict["checkDisplayName"] = check_display_name
        if check_type is not UNSET:
            field_dict["checkType"] = check_type
        if check_hash is not UNSET:
            field_dict["checkHash"] = check_hash
        if check_category is not UNSET:
            field_dict["checkCategory"] = check_category
        if sensor_name is not UNSET:
            field_dict["sensorName"] = sensor_name
        if data_group_names is not UNSET:
            field_dict["dataGroupNames"] = data_group_names
        if data_group is not UNSET:
            field_dict["dataGroup"] = data_group
        if single_sensor_readouts is not UNSET:
            field_dict["singleSensorReadouts"] = single_sensor_readouts

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.sensor_readout_detailed_single_model import (
            SensorReadoutDetailedSingleModel,
        )

        d = src_dict.copy()
        check_name = d.pop("checkName", UNSET)

        check_display_name = d.pop("checkDisplayName", UNSET)

        check_type = d.pop("checkType", UNSET)

        check_hash = d.pop("checkHash", UNSET)

        check_category = d.pop("checkCategory", UNSET)

        sensor_name = d.pop("sensorName", UNSET)

        data_group_names = cast(List[str], d.pop("dataGroupNames", UNSET))

        data_group = d.pop("dataGroup", UNSET)

        single_sensor_readouts = []
        _single_sensor_readouts = d.pop("singleSensorReadouts", UNSET)
        for single_sensor_readouts_item_data in _single_sensor_readouts or []:
            single_sensor_readouts_item = SensorReadoutDetailedSingleModel.from_dict(
                single_sensor_readouts_item_data
            )

            single_sensor_readouts.append(single_sensor_readouts_item)

        sensor_readouts_detailed_data_model = cls(
            check_name=check_name,
            check_display_name=check_display_name,
            check_type=check_type,
            check_hash=check_hash,
            check_category=check_category,
            sensor_name=sensor_name,
            data_group_names=data_group_names,
            data_group=data_group,
            single_sensor_readouts=single_sensor_readouts,
        )

        sensor_readouts_detailed_data_model.additional_properties = d
        return sensor_readouts_detailed_data_model

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

import attr

from ..models.table_profiling_check_categories_spec_result_truncation import (
    TableProfilingCheckCategoriesSpecResultTruncation,
)
from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.table_accuracy_profiling_checks_spec import (
        TableAccuracyProfilingChecksSpec,
    )
    from ..models.table_availability_profiling_checks_spec import (
        TableAvailabilityProfilingChecksSpec,
    )
    from ..models.table_profiling_check_categories_spec_comparisons import (
        TableProfilingCheckCategoriesSpecComparisons,
    )
    from ..models.table_profiling_check_categories_spec_custom import (
        TableProfilingCheckCategoriesSpecCustom,
    )
    from ..models.table_schema_profiling_checks_spec import (
        TableSchemaProfilingChecksSpec,
    )
    from ..models.table_sql_profiling_checks_spec import TableSqlProfilingChecksSpec
    from ..models.table_timeliness_profiling_checks_spec import (
        TableTimelinessProfilingChecksSpec,
    )
    from ..models.table_volume_profiling_checks_spec import (
        TableVolumeProfilingChecksSpec,
    )


T = TypeVar("T", bound="TableProfilingCheckCategoriesSpec")


@attr.s(auto_attribs=True)
class TableProfilingCheckCategoriesSpec:
    """
    Attributes:
        custom (Union[Unset, TableProfilingCheckCategoriesSpecCustom]): Dictionary of custom checks. The keys are check
            names.
        result_truncation (Union[Unset, TableProfilingCheckCategoriesSpecResultTruncation]): Defines how many advanced
            profiling results are stored for the table monthly. By default, DQO will use the 'one_per_month' configuration
            and store only the most recent advanced profiling result executed during the month. By changing this value, it
            is possible to store one value per day or even store all advanced profiling results.
        volume (Union[Unset, TableVolumeProfilingChecksSpec]):
        timeliness (Union[Unset, TableTimelinessProfilingChecksSpec]):
        accuracy (Union[Unset, TableAccuracyProfilingChecksSpec]):
        sql (Union[Unset, TableSqlProfilingChecksSpec]):
        availability (Union[Unset, TableAvailabilityProfilingChecksSpec]):
        schema (Union[Unset, TableSchemaProfilingChecksSpec]):
        comparisons (Union[Unset, TableProfilingCheckCategoriesSpecComparisons]): Dictionary of configuration of checks
            for table comparisons. The key that identifies each comparison must match the name of a data comparison that is
            configured on the parent table.
    """

    custom: Union[Unset, "TableProfilingCheckCategoriesSpecCustom"] = UNSET
    result_truncation: Union[
        Unset, TableProfilingCheckCategoriesSpecResultTruncation
    ] = UNSET
    volume: Union[Unset, "TableVolumeProfilingChecksSpec"] = UNSET
    timeliness: Union[Unset, "TableTimelinessProfilingChecksSpec"] = UNSET
    accuracy: Union[Unset, "TableAccuracyProfilingChecksSpec"] = UNSET
    sql: Union[Unset, "TableSqlProfilingChecksSpec"] = UNSET
    availability: Union[Unset, "TableAvailabilityProfilingChecksSpec"] = UNSET
    schema: Union[Unset, "TableSchemaProfilingChecksSpec"] = UNSET
    comparisons: Union[Unset, "TableProfilingCheckCategoriesSpecComparisons"] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        custom: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.custom, Unset):
            custom = self.custom.to_dict()

        result_truncation: Union[Unset, str] = UNSET
        if not isinstance(self.result_truncation, Unset):
            result_truncation = self.result_truncation.value

        volume: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.volume, Unset):
            volume = self.volume.to_dict()

        timeliness: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.timeliness, Unset):
            timeliness = self.timeliness.to_dict()

        accuracy: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.accuracy, Unset):
            accuracy = self.accuracy.to_dict()

        sql: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.sql, Unset):
            sql = self.sql.to_dict()

        availability: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.availability, Unset):
            availability = self.availability.to_dict()

        schema: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.schema, Unset):
            schema = self.schema.to_dict()

        comparisons: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.comparisons, Unset):
            comparisons = self.comparisons.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if custom is not UNSET:
            field_dict["custom"] = custom
        if result_truncation is not UNSET:
            field_dict["result_truncation"] = result_truncation
        if volume is not UNSET:
            field_dict["volume"] = volume
        if timeliness is not UNSET:
            field_dict["timeliness"] = timeliness
        if accuracy is not UNSET:
            field_dict["accuracy"] = accuracy
        if sql is not UNSET:
            field_dict["sql"] = sql
        if availability is not UNSET:
            field_dict["availability"] = availability
        if schema is not UNSET:
            field_dict["schema"] = schema
        if comparisons is not UNSET:
            field_dict["comparisons"] = comparisons

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.table_accuracy_profiling_checks_spec import (
            TableAccuracyProfilingChecksSpec,
        )
        from ..models.table_availability_profiling_checks_spec import (
            TableAvailabilityProfilingChecksSpec,
        )
        from ..models.table_profiling_check_categories_spec_comparisons import (
            TableProfilingCheckCategoriesSpecComparisons,
        )
        from ..models.table_profiling_check_categories_spec_custom import (
            TableProfilingCheckCategoriesSpecCustom,
        )
        from ..models.table_schema_profiling_checks_spec import (
            TableSchemaProfilingChecksSpec,
        )
        from ..models.table_sql_profiling_checks_spec import TableSqlProfilingChecksSpec
        from ..models.table_timeliness_profiling_checks_spec import (
            TableTimelinessProfilingChecksSpec,
        )
        from ..models.table_volume_profiling_checks_spec import (
            TableVolumeProfilingChecksSpec,
        )

        d = src_dict.copy()
        _custom = d.pop("custom", UNSET)
        custom: Union[Unset, TableProfilingCheckCategoriesSpecCustom]
        if isinstance(_custom, Unset):
            custom = UNSET
        else:
            custom = TableProfilingCheckCategoriesSpecCustom.from_dict(_custom)

        _result_truncation = d.pop("result_truncation", UNSET)
        result_truncation: Union[
            Unset, TableProfilingCheckCategoriesSpecResultTruncation
        ]
        if isinstance(_result_truncation, Unset):
            result_truncation = UNSET
        else:
            result_truncation = TableProfilingCheckCategoriesSpecResultTruncation(
                _result_truncation
            )

        _volume = d.pop("volume", UNSET)
        volume: Union[Unset, TableVolumeProfilingChecksSpec]
        if isinstance(_volume, Unset):
            volume = UNSET
        else:
            volume = TableVolumeProfilingChecksSpec.from_dict(_volume)

        _timeliness = d.pop("timeliness", UNSET)
        timeliness: Union[Unset, TableTimelinessProfilingChecksSpec]
        if isinstance(_timeliness, Unset):
            timeliness = UNSET
        else:
            timeliness = TableTimelinessProfilingChecksSpec.from_dict(_timeliness)

        _accuracy = d.pop("accuracy", UNSET)
        accuracy: Union[Unset, TableAccuracyProfilingChecksSpec]
        if isinstance(_accuracy, Unset):
            accuracy = UNSET
        else:
            accuracy = TableAccuracyProfilingChecksSpec.from_dict(_accuracy)

        _sql = d.pop("sql", UNSET)
        sql: Union[Unset, TableSqlProfilingChecksSpec]
        if isinstance(_sql, Unset):
            sql = UNSET
        else:
            sql = TableSqlProfilingChecksSpec.from_dict(_sql)

        _availability = d.pop("availability", UNSET)
        availability: Union[Unset, TableAvailabilityProfilingChecksSpec]
        if isinstance(_availability, Unset):
            availability = UNSET
        else:
            availability = TableAvailabilityProfilingChecksSpec.from_dict(_availability)

        _schema = d.pop("schema", UNSET)
        schema: Union[Unset, TableSchemaProfilingChecksSpec]
        if isinstance(_schema, Unset):
            schema = UNSET
        else:
            schema = TableSchemaProfilingChecksSpec.from_dict(_schema)

        _comparisons = d.pop("comparisons", UNSET)
        comparisons: Union[Unset, TableProfilingCheckCategoriesSpecComparisons]
        if isinstance(_comparisons, Unset):
            comparisons = UNSET
        else:
            comparisons = TableProfilingCheckCategoriesSpecComparisons.from_dict(
                _comparisons
            )

        table_profiling_check_categories_spec = cls(
            custom=custom,
            result_truncation=result_truncation,
            volume=volume,
            timeliness=timeliness,
            accuracy=accuracy,
            sql=sql,
            availability=availability,
            schema=schema,
            comparisons=comparisons,
        )

        table_profiling_check_categories_spec.additional_properties = d
        return table_profiling_check_categories_spec

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.check_search_filters import CheckSearchFilters
    from ..models.delete_stored_data_queue_job_parameters import (
        DeleteStoredDataQueueJobParameters,
    )
    from ..models.physical_table_name import PhysicalTableName
    from ..models.statistics_collector_search_filters import (
        StatisticsCollectorSearchFilters,
    )
    from ..models.table_owner_spec import TableOwnerSpec


T = TypeVar("T", bound="TableBasicModel")


@attr.s(auto_attribs=True)
class TableBasicModel:
    """Basic table model with a subset of parameters, excluding all nested objects.

    Attributes:
        connection_name (Union[Unset, str]): Connection name.
        table_hash (Union[Unset, int]): Table hash that identifies the table using a unique hash code.
        target (Union[Unset, PhysicalTableName]):
        disabled (Union[Unset, bool]): Disables all data quality checks on the table. Data quality checks will not be
            executed.
        stage (Union[Unset, str]): Stage name.
        filter_ (Union[Unset, str]): SQL WHERE clause added to the sensor queries.
        priority (Union[Unset, int]): Table priority (1, 2, 3, 4, ...). The tables could be assigned a priority level.
            The table priority is copied into each data quality check result and a sensor result, enabling efficient
            grouping of more and less important tables during a data quality improvement project, when the data quality
            issues on higher priority tables are fixed before data quality issues on less important tables.
        owner (Union[Unset, TableOwnerSpec]):
        has_any_configured_checks (Union[Unset, bool]): True when the table has any checks configured.
        has_any_configured_profiling_checks (Union[Unset, bool]): True when the table has any profiling checks
            configured.
        has_any_configured_recurring_checks (Union[Unset, bool]): True when the table has any recurring checks
            configured.
        has_any_configured_partition_checks (Union[Unset, bool]): True when the table has any partition checks
            configured.
        partitioning_configuration_missing (Union[Unset, bool]): True when the table has missing configuration of the
            "partition_by_column" column, making any partition checks fail when executed.
        run_checks_job_template (Union[Unset, CheckSearchFilters]): Target data quality checks filter, identifies which
            checks on which tables and columns should be executed.
        run_profiling_checks_job_template (Union[Unset, CheckSearchFilters]): Target data quality checks filter,
            identifies which checks on which tables and columns should be executed.
        run_recurring_checks_job_template (Union[Unset, CheckSearchFilters]): Target data quality checks filter,
            identifies which checks on which tables and columns should be executed.
        run_partition_checks_job_template (Union[Unset, CheckSearchFilters]): Target data quality checks filter,
            identifies which checks on which tables and columns should be executed.
        collect_statistics_job_template (Union[Unset, StatisticsCollectorSearchFilters]):
        data_clean_job_template (Union[Unset, DeleteStoredDataQueueJobParameters]):
    """

    connection_name: Union[Unset, str] = UNSET
    table_hash: Union[Unset, int] = UNSET
    target: Union[Unset, "PhysicalTableName"] = UNSET
    disabled: Union[Unset, bool] = UNSET
    stage: Union[Unset, str] = UNSET
    filter_: Union[Unset, str] = UNSET
    priority: Union[Unset, int] = UNSET
    owner: Union[Unset, "TableOwnerSpec"] = UNSET
    has_any_configured_checks: Union[Unset, bool] = UNSET
    has_any_configured_profiling_checks: Union[Unset, bool] = UNSET
    has_any_configured_recurring_checks: Union[Unset, bool] = UNSET
    has_any_configured_partition_checks: Union[Unset, bool] = UNSET
    partitioning_configuration_missing: Union[Unset, bool] = UNSET
    run_checks_job_template: Union[Unset, "CheckSearchFilters"] = UNSET
    run_profiling_checks_job_template: Union[Unset, "CheckSearchFilters"] = UNSET
    run_recurring_checks_job_template: Union[Unset, "CheckSearchFilters"] = UNSET
    run_partition_checks_job_template: Union[Unset, "CheckSearchFilters"] = UNSET
    collect_statistics_job_template: Union[
        Unset, "StatisticsCollectorSearchFilters"
    ] = UNSET
    data_clean_job_template: Union[Unset, "DeleteStoredDataQueueJobParameters"] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        connection_name = self.connection_name
        table_hash = self.table_hash
        target: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.target, Unset):
            target = self.target.to_dict()

        disabled = self.disabled
        stage = self.stage
        filter_ = self.filter_
        priority = self.priority
        owner: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.owner, Unset):
            owner = self.owner.to_dict()

        has_any_configured_checks = self.has_any_configured_checks
        has_any_configured_profiling_checks = self.has_any_configured_profiling_checks
        has_any_configured_recurring_checks = self.has_any_configured_recurring_checks
        has_any_configured_partition_checks = self.has_any_configured_partition_checks
        partitioning_configuration_missing = self.partitioning_configuration_missing
        run_checks_job_template: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.run_checks_job_template, Unset):
            run_checks_job_template = self.run_checks_job_template.to_dict()

        run_profiling_checks_job_template: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.run_profiling_checks_job_template, Unset):
            run_profiling_checks_job_template = (
                self.run_profiling_checks_job_template.to_dict()
            )

        run_recurring_checks_job_template: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.run_recurring_checks_job_template, Unset):
            run_recurring_checks_job_template = (
                self.run_recurring_checks_job_template.to_dict()
            )

        run_partition_checks_job_template: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.run_partition_checks_job_template, Unset):
            run_partition_checks_job_template = (
                self.run_partition_checks_job_template.to_dict()
            )

        collect_statistics_job_template: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.collect_statistics_job_template, Unset):
            collect_statistics_job_template = (
                self.collect_statistics_job_template.to_dict()
            )

        data_clean_job_template: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.data_clean_job_template, Unset):
            data_clean_job_template = self.data_clean_job_template.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if connection_name is not UNSET:
            field_dict["connection_name"] = connection_name
        if table_hash is not UNSET:
            field_dict["table_hash"] = table_hash
        if target is not UNSET:
            field_dict["target"] = target
        if disabled is not UNSET:
            field_dict["disabled"] = disabled
        if stage is not UNSET:
            field_dict["stage"] = stage
        if filter_ is not UNSET:
            field_dict["filter"] = filter_
        if priority is not UNSET:
            field_dict["priority"] = priority
        if owner is not UNSET:
            field_dict["owner"] = owner
        if has_any_configured_checks is not UNSET:
            field_dict["has_any_configured_checks"] = has_any_configured_checks
        if has_any_configured_profiling_checks is not UNSET:
            field_dict[
                "has_any_configured_profiling_checks"
            ] = has_any_configured_profiling_checks
        if has_any_configured_recurring_checks is not UNSET:
            field_dict[
                "has_any_configured_recurring_checks"
            ] = has_any_configured_recurring_checks
        if has_any_configured_partition_checks is not UNSET:
            field_dict[
                "has_any_configured_partition_checks"
            ] = has_any_configured_partition_checks
        if partitioning_configuration_missing is not UNSET:
            field_dict[
                "partitioning_configuration_missing"
            ] = partitioning_configuration_missing
        if run_checks_job_template is not UNSET:
            field_dict["run_checks_job_template"] = run_checks_job_template
        if run_profiling_checks_job_template is not UNSET:
            field_dict[
                "run_profiling_checks_job_template"
            ] = run_profiling_checks_job_template
        if run_recurring_checks_job_template is not UNSET:
            field_dict[
                "run_recurring_checks_job_template"
            ] = run_recurring_checks_job_template
        if run_partition_checks_job_template is not UNSET:
            field_dict[
                "run_partition_checks_job_template"
            ] = run_partition_checks_job_template
        if collect_statistics_job_template is not UNSET:
            field_dict[
                "collect_statistics_job_template"
            ] = collect_statistics_job_template
        if data_clean_job_template is not UNSET:
            field_dict["data_clean_job_template"] = data_clean_job_template

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.check_search_filters import CheckSearchFilters
        from ..models.delete_stored_data_queue_job_parameters import (
            DeleteStoredDataQueueJobParameters,
        )
        from ..models.physical_table_name import PhysicalTableName
        from ..models.statistics_collector_search_filters import (
            StatisticsCollectorSearchFilters,
        )
        from ..models.table_owner_spec import TableOwnerSpec

        d = src_dict.copy()
        connection_name = d.pop("connection_name", UNSET)

        table_hash = d.pop("table_hash", UNSET)

        _target = d.pop("target", UNSET)
        target: Union[Unset, PhysicalTableName]
        if isinstance(_target, Unset):
            target = UNSET
        else:
            target = PhysicalTableName.from_dict(_target)

        disabled = d.pop("disabled", UNSET)

        stage = d.pop("stage", UNSET)

        filter_ = d.pop("filter", UNSET)

        priority = d.pop("priority", UNSET)

        _owner = d.pop("owner", UNSET)
        owner: Union[Unset, TableOwnerSpec]
        if isinstance(_owner, Unset):
            owner = UNSET
        else:
            owner = TableOwnerSpec.from_dict(_owner)

        has_any_configured_checks = d.pop("has_any_configured_checks", UNSET)

        has_any_configured_profiling_checks = d.pop(
            "has_any_configured_profiling_checks", UNSET
        )

        has_any_configured_recurring_checks = d.pop(
            "has_any_configured_recurring_checks", UNSET
        )

        has_any_configured_partition_checks = d.pop(
            "has_any_configured_partition_checks", UNSET
        )

        partitioning_configuration_missing = d.pop(
            "partitioning_configuration_missing", UNSET
        )

        _run_checks_job_template = d.pop("run_checks_job_template", UNSET)
        run_checks_job_template: Union[Unset, CheckSearchFilters]
        if isinstance(_run_checks_job_template, Unset):
            run_checks_job_template = UNSET
        else:
            run_checks_job_template = CheckSearchFilters.from_dict(
                _run_checks_job_template
            )

        _run_profiling_checks_job_template = d.pop(
            "run_profiling_checks_job_template", UNSET
        )
        run_profiling_checks_job_template: Union[Unset, CheckSearchFilters]
        if isinstance(_run_profiling_checks_job_template, Unset):
            run_profiling_checks_job_template = UNSET
        else:
            run_profiling_checks_job_template = CheckSearchFilters.from_dict(
                _run_profiling_checks_job_template
            )

        _run_recurring_checks_job_template = d.pop(
            "run_recurring_checks_job_template", UNSET
        )
        run_recurring_checks_job_template: Union[Unset, CheckSearchFilters]
        if isinstance(_run_recurring_checks_job_template, Unset):
            run_recurring_checks_job_template = UNSET
        else:
            run_recurring_checks_job_template = CheckSearchFilters.from_dict(
                _run_recurring_checks_job_template
            )

        _run_partition_checks_job_template = d.pop(
            "run_partition_checks_job_template", UNSET
        )
        run_partition_checks_job_template: Union[Unset, CheckSearchFilters]
        if isinstance(_run_partition_checks_job_template, Unset):
            run_partition_checks_job_template = UNSET
        else:
            run_partition_checks_job_template = CheckSearchFilters.from_dict(
                _run_partition_checks_job_template
            )

        _collect_statistics_job_template = d.pop(
            "collect_statistics_job_template", UNSET
        )
        collect_statistics_job_template: Union[Unset, StatisticsCollectorSearchFilters]
        if isinstance(_collect_statistics_job_template, Unset):
            collect_statistics_job_template = UNSET
        else:
            collect_statistics_job_template = (
                StatisticsCollectorSearchFilters.from_dict(
                    _collect_statistics_job_template
                )
            )

        _data_clean_job_template = d.pop("data_clean_job_template", UNSET)
        data_clean_job_template: Union[Unset, DeleteStoredDataQueueJobParameters]
        if isinstance(_data_clean_job_template, Unset):
            data_clean_job_template = UNSET
        else:
            data_clean_job_template = DeleteStoredDataQueueJobParameters.from_dict(
                _data_clean_job_template
            )

        table_basic_model = cls(
            connection_name=connection_name,
            table_hash=table_hash,
            target=target,
            disabled=disabled,
            stage=stage,
            filter_=filter_,
            priority=priority,
            owner=owner,
            has_any_configured_checks=has_any_configured_checks,
            has_any_configured_profiling_checks=has_any_configured_profiling_checks,
            has_any_configured_recurring_checks=has_any_configured_recurring_checks,
            has_any_configured_partition_checks=has_any_configured_partition_checks,
            partitioning_configuration_missing=partitioning_configuration_missing,
            run_checks_job_template=run_checks_job_template,
            run_profiling_checks_job_template=run_profiling_checks_job_template,
            run_recurring_checks_job_template=run_recurring_checks_job_template,
            run_partition_checks_job_template=run_partition_checks_job_template,
            collect_statistics_job_template=collect_statistics_job_template,
            data_clean_job_template=data_clean_job_template,
        )

        table_basic_model.additional_properties = d
        return table_basic_model

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.provider_sensor_basic_model import ProviderSensorBasicModel


T = TypeVar("T", bound="SensorBasicModel")


@attr.s(auto_attribs=True)
class SensorBasicModel:
    """Sensor basic model

    Attributes:
        sensor_name (Union[Unset, str]): Sensor name
        full_sensor_name (Union[Unset, str]): Full sensor name
        custom (Union[Unset, bool]): This sensor has is a custom sensor or was customized by the user.
        built_in (Union[Unset, bool]): This sensor is provided with DQO as a built-in sensor.
        provider_sensor_basic_models (Union[Unset, List['ProviderSensorBasicModel']]): Provider sensor basic model list
    """

    sensor_name: Union[Unset, str] = UNSET
    full_sensor_name: Union[Unset, str] = UNSET
    custom: Union[Unset, bool] = UNSET
    built_in: Union[Unset, bool] = UNSET
    provider_sensor_basic_models: Union[Unset, List["ProviderSensorBasicModel"]] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        sensor_name = self.sensor_name
        full_sensor_name = self.full_sensor_name
        custom = self.custom
        built_in = self.built_in
        provider_sensor_basic_models: Union[Unset, List[Dict[str, Any]]] = UNSET
        if not isinstance(self.provider_sensor_basic_models, Unset):
            provider_sensor_basic_models = []
            for (
                provider_sensor_basic_models_item_data
            ) in self.provider_sensor_basic_models:
                provider_sensor_basic_models_item = (
                    provider_sensor_basic_models_item_data.to_dict()
                )

                provider_sensor_basic_models.append(provider_sensor_basic_models_item)

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if sensor_name is not UNSET:
            field_dict["sensor_name"] = sensor_name
        if full_sensor_name is not UNSET:
            field_dict["full_sensor_name"] = full_sensor_name
        if custom is not UNSET:
            field_dict["custom"] = custom
        if built_in is not UNSET:
            field_dict["built_in"] = built_in
        if provider_sensor_basic_models is not UNSET:
            field_dict["provider_sensor_basic_models"] = provider_sensor_basic_models

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.provider_sensor_basic_model import ProviderSensorBasicModel

        d = src_dict.copy()
        sensor_name = d.pop("sensor_name", UNSET)

        full_sensor_name = d.pop("full_sensor_name", UNSET)

        custom = d.pop("custom", UNSET)

        built_in = d.pop("built_in", UNSET)

        provider_sensor_basic_models = []
        _provider_sensor_basic_models = d.pop("provider_sensor_basic_models", UNSET)
        for provider_sensor_basic_models_item_data in (
            _provider_sensor_basic_models or []
        ):
            provider_sensor_basic_models_item = ProviderSensorBasicModel.from_dict(
                provider_sensor_basic_models_item_data
            )

            provider_sensor_basic_models.append(provider_sensor_basic_models_item)

        sensor_basic_model = cls(
            sensor_name=sensor_name,
            full_sensor_name=full_sensor_name,
            custom=custom,
            built_in=built_in,
            provider_sensor_basic_models=provider_sensor_basic_models,
        )

        sensor_basic_model.additional_properties = d
        return sensor_basic_model

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

T = TypeVar("T", bound="ExternalLogEntry")


@attr.s(auto_attribs=True)
class ExternalLogEntry:
    """External log entry

    Attributes:
        window_location (Union[Unset, str]): window.location value at the time when the log entry was reported.
        message (Union[Unset, str]): Log message that should be logged.
    """

    window_location: Union[Unset, str] = UNSET
    message: Union[Unset, str] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        window_location = self.window_location
        message = self.message

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if window_location is not UNSET:
            field_dict["window_location"] = window_location
        if message is not UNSET:
            field_dict["message"] = message

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        window_location = d.pop("window_location", UNSET)

        message = d.pop("message", UNSET)

        external_log_entry = cls(
            window_location=window_location,
            message=message,
        )

        external_log_entry.additional_properties = d
        return external_log_entry

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union, cast

import attr

from ..models.check_search_filters_check_target import CheckSearchFiltersCheckTarget
from ..models.check_search_filters_check_type import CheckSearchFiltersCheckType
from ..models.check_search_filters_time_scale import CheckSearchFiltersTimeScale
from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.hierarchy_id_model import HierarchyIdModel


T = TypeVar("T", bound="CheckSearchFilters")


@attr.s(auto_attribs=True)
class CheckSearchFilters:
    """Target data quality checks filter, identifies which checks on which tables and columns should be executed.

    Attributes:
        connection_name (Union[Unset, str]):
        schema_table_name (Union[Unset, str]):
        enabled (Union[Unset, bool]):
        tags (Union[Unset, List[str]]):
        labels (Union[Unset, List[str]]):
        column_name (Union[Unset, str]):
        column_data_type (Union[Unset, str]):
        column_nullable (Union[Unset, bool]):
        check_target (Union[Unset, CheckSearchFiltersCheckTarget]):
        check_type (Union[Unset, CheckSearchFiltersCheckType]):
        time_scale (Union[Unset, CheckSearchFiltersTimeScale]):
        check_category (Union[Unset, str]):
        table_comparison_name (Union[Unset, str]):
        check_name (Union[Unset, str]):
        sensor_name (Union[Unset, str]):
        check_configured (Union[Unset, bool]):
        check_hierarchy_ids_models (Union[Unset, List['HierarchyIdModel']]):
    """

    connection_name: Union[Unset, str] = UNSET
    schema_table_name: Union[Unset, str] = UNSET
    enabled: Union[Unset, bool] = UNSET
    tags: Union[Unset, List[str]] = UNSET
    labels: Union[Unset, List[str]] = UNSET
    column_name: Union[Unset, str] = UNSET
    column_data_type: Union[Unset, str] = UNSET
    column_nullable: Union[Unset, bool] = UNSET
    check_target: Union[Unset, CheckSearchFiltersCheckTarget] = UNSET
    check_type: Union[Unset, CheckSearchFiltersCheckType] = UNSET
    time_scale: Union[Unset, CheckSearchFiltersTimeScale] = UNSET
    check_category: Union[Unset, str] = UNSET
    table_comparison_name: Union[Unset, str] = UNSET
    check_name: Union[Unset, str] = UNSET
    sensor_name: Union[Unset, str] = UNSET
    check_configured: Union[Unset, bool] = UNSET
    check_hierarchy_ids_models: Union[Unset, List["HierarchyIdModel"]] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        connection_name = self.connection_name
        schema_table_name = self.schema_table_name
        enabled = self.enabled
        tags: Union[Unset, List[str]] = UNSET
        if not isinstance(self.tags, Unset):
            tags = self.tags

        labels: Union[Unset, List[str]] = UNSET
        if not isinstance(self.labels, Unset):
            labels = self.labels

        column_name = self.column_name
        column_data_type = self.column_data_type
        column_nullable = self.column_nullable
        check_target: Union[Unset, str] = UNSET
        if not isinstance(self.check_target, Unset):
            check_target = self.check_target.value

        check_type: Union[Unset, str] = UNSET
        if not isinstance(self.check_type, Unset):
            check_type = self.check_type.value

        time_scale: Union[Unset, str] = UNSET
        if not isinstance(self.time_scale, Unset):
            time_scale = self.time_scale.value

        check_category = self.check_category
        table_comparison_name = self.table_comparison_name
        check_name = self.check_name
        sensor_name = self.sensor_name
        check_configured = self.check_configured
        check_hierarchy_ids_models: Union[Unset, List[Dict[str, Any]]] = UNSET
        if not isinstance(self.check_hierarchy_ids_models, Unset):
            check_hierarchy_ids_models = []
            for check_hierarchy_ids_models_item_data in self.check_hierarchy_ids_models:
                check_hierarchy_ids_models_item = (
                    check_hierarchy_ids_models_item_data.to_dict()
                )

                check_hierarchy_ids_models.append(check_hierarchy_ids_models_item)

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if connection_name is not UNSET:
            field_dict["connectionName"] = connection_name
        if schema_table_name is not UNSET:
            field_dict["schemaTableName"] = schema_table_name
        if enabled is not UNSET:
            field_dict["enabled"] = enabled
        if tags is not UNSET:
            field_dict["tags"] = tags
        if labels is not UNSET:
            field_dict["labels"] = labels
        if column_name is not UNSET:
            field_dict["columnName"] = column_name
        if column_data_type is not UNSET:
            field_dict["columnDataType"] = column_data_type
        if column_nullable is not UNSET:
            field_dict["columnNullable"] = column_nullable
        if check_target is not UNSET:
            field_dict["checkTarget"] = check_target
        if check_type is not UNSET:
            field_dict["checkType"] = check_type
        if time_scale is not UNSET:
            field_dict["timeScale"] = time_scale
        if check_category is not UNSET:
            field_dict["checkCategory"] = check_category
        if table_comparison_name is not UNSET:
            field_dict["tableComparisonName"] = table_comparison_name
        if check_name is not UNSET:
            field_dict["checkName"] = check_name
        if sensor_name is not UNSET:
            field_dict["sensorName"] = sensor_name
        if check_configured is not UNSET:
            field_dict["checkConfigured"] = check_configured
        if check_hierarchy_ids_models is not UNSET:
            field_dict["checkHierarchyIdsModels"] = check_hierarchy_ids_models

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.hierarchy_id_model import HierarchyIdModel

        d = src_dict.copy()
        connection_name = d.pop("connectionName", UNSET)

        schema_table_name = d.pop("schemaTableName", UNSET)

        enabled = d.pop("enabled", UNSET)

        tags = cast(List[str], d.pop("tags", UNSET))

        labels = cast(List[str], d.pop("labels", UNSET))

        column_name = d.pop("columnName", UNSET)

        column_data_type = d.pop("columnDataType", UNSET)

        column_nullable = d.pop("columnNullable", UNSET)

        _check_target = d.pop("checkTarget", UNSET)
        check_target: Union[Unset, CheckSearchFiltersCheckTarget]
        if isinstance(_check_target, Unset):
            check_target = UNSET
        else:
            check_target = CheckSearchFiltersCheckTarget(_check_target)

        _check_type = d.pop("checkType", UNSET)
        check_type: Union[Unset, CheckSearchFiltersCheckType]
        if isinstance(_check_type, Unset):
            check_type = UNSET
        else:
            check_type = CheckSearchFiltersCheckType(_check_type)

        _time_scale = d.pop("timeScale", UNSET)
        time_scale: Union[Unset, CheckSearchFiltersTimeScale]
        if isinstance(_time_scale, Unset):
            time_scale = UNSET
        else:
            time_scale = CheckSearchFiltersTimeScale(_time_scale)

        check_category = d.pop("checkCategory", UNSET)

        table_comparison_name = d.pop("tableComparisonName", UNSET)

        check_name = d.pop("checkName", UNSET)

        sensor_name = d.pop("sensorName", UNSET)

        check_configured = d.pop("checkConfigured", UNSET)

        check_hierarchy_ids_models = []
        _check_hierarchy_ids_models = d.pop("checkHierarchyIdsModels", UNSET)
        for check_hierarchy_ids_models_item_data in _check_hierarchy_ids_models or []:
            check_hierarchy_ids_models_item = HierarchyIdModel.from_dict(
                check_hierarchy_ids_models_item_data
            )

            check_hierarchy_ids_models.append(check_hierarchy_ids_models_item)

        check_search_filters = cls(
            connection_name=connection_name,
            schema_table_name=schema_table_name,
            enabled=enabled,
            tags=tags,
            labels=labels,
            column_name=column_name,
            column_data_type=column_data_type,
            column_nullable=column_nullable,
            check_target=check_target,
            check_type=check_type,
            time_scale=time_scale,
            check_category=check_category,
            table_comparison_name=table_comparison_name,
            check_name=check_name,
            sensor_name=sensor_name,
            check_configured=check_configured,
            check_hierarchy_ids_models=check_hierarchy_ids_models,
        )

        check_search_filters.additional_properties = d
        return check_search_filters

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.column_change_mean_check_spec import ColumnChangeMeanCheckSpec
    from ..models.column_change_median_check_spec import ColumnChangeMedianCheckSpec
    from ..models.column_change_sum_check_spec import ColumnChangeSumCheckSpec


T = TypeVar("T", bound="ColumnAnomalyMonthlyPartitionedChecksSpec")


@attr.s(auto_attribs=True)
class ColumnAnomalyMonthlyPartitionedChecksSpec:
    """
    Attributes:
        monthly_partition_mean_change (Union[Unset, ColumnChangeMeanCheckSpec]):
        monthly_partition_median_change (Union[Unset, ColumnChangeMedianCheckSpec]):
        monthly_partition_sum_change (Union[Unset, ColumnChangeSumCheckSpec]):
    """

    monthly_partition_mean_change: Union[Unset, "ColumnChangeMeanCheckSpec"] = UNSET
    monthly_partition_median_change: Union[Unset, "ColumnChangeMedianCheckSpec"] = UNSET
    monthly_partition_sum_change: Union[Unset, "ColumnChangeSumCheckSpec"] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        monthly_partition_mean_change: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.monthly_partition_mean_change, Unset):
            monthly_partition_mean_change = self.monthly_partition_mean_change.to_dict()

        monthly_partition_median_change: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.monthly_partition_median_change, Unset):
            monthly_partition_median_change = (
                self.monthly_partition_median_change.to_dict()
            )

        monthly_partition_sum_change: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.monthly_partition_sum_change, Unset):
            monthly_partition_sum_change = self.monthly_partition_sum_change.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if monthly_partition_mean_change is not UNSET:
            field_dict["monthly_partition_mean_change"] = monthly_partition_mean_change
        if monthly_partition_median_change is not UNSET:
            field_dict[
                "monthly_partition_median_change"
            ] = monthly_partition_median_change
        if monthly_partition_sum_change is not UNSET:
            field_dict["monthly_partition_sum_change"] = monthly_partition_sum_change

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.column_change_mean_check_spec import ColumnChangeMeanCheckSpec
        from ..models.column_change_median_check_spec import ColumnChangeMedianCheckSpec
        from ..models.column_change_sum_check_spec import ColumnChangeSumCheckSpec

        d = src_dict.copy()
        _monthly_partition_mean_change = d.pop("monthly_partition_mean_change", UNSET)
        monthly_partition_mean_change: Union[Unset, ColumnChangeMeanCheckSpec]
        if isinstance(_monthly_partition_mean_change, Unset):
            monthly_partition_mean_change = UNSET
        else:
            monthly_partition_mean_change = ColumnChangeMeanCheckSpec.from_dict(
                _monthly_partition_mean_change
            )

        _monthly_partition_median_change = d.pop(
            "monthly_partition_median_change", UNSET
        )
        monthly_partition_median_change: Union[Unset, ColumnChangeMedianCheckSpec]
        if isinstance(_monthly_partition_median_change, Unset):
            monthly_partition_median_change = UNSET
        else:
            monthly_partition_median_change = ColumnChangeMedianCheckSpec.from_dict(
                _monthly_partition_median_change
            )

        _monthly_partition_sum_change = d.pop("monthly_partition_sum_change", UNSET)
        monthly_partition_sum_change: Union[Unset, ColumnChangeSumCheckSpec]
        if isinstance(_monthly_partition_sum_change, Unset):
            monthly_partition_sum_change = UNSET
        else:
            monthly_partition_sum_change = ColumnChangeSumCheckSpec.from_dict(
                _monthly_partition_sum_change
            )

        column_anomaly_monthly_partitioned_checks_spec = cls(
            monthly_partition_mean_change=monthly_partition_mean_change,
            monthly_partition_median_change=monthly_partition_median_change,
            monthly_partition_sum_change=monthly_partition_sum_change,
        )

        column_anomaly_monthly_partitioned_checks_spec.additional_properties = d
        return column_anomaly_monthly_partitioned_checks_spec

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.table_sql_aggregate_expr_check_spec import (
        TableSqlAggregateExprCheckSpec,
    )
    from ..models.table_sql_condition_failed_count_check_spec import (
        TableSqlConditionFailedCountCheckSpec,
    )
    from ..models.table_sql_condition_passed_percent_check_spec import (
        TableSqlConditionPassedPercentCheckSpec,
    )


T = TypeVar("T", bound="TableSqlDailyRecurringChecksSpec")


@attr.s(auto_attribs=True)
class TableSqlDailyRecurringChecksSpec:
    """
    Attributes:
        daily_sql_condition_passed_percent_on_table (Union[Unset, TableSqlConditionPassedPercentCheckSpec]):
        daily_sql_condition_failed_count_on_table (Union[Unset, TableSqlConditionFailedCountCheckSpec]):
        daily_sql_aggregate_expr_table (Union[Unset, TableSqlAggregateExprCheckSpec]):
        min_sql_condition_passed_percent_on_table (Union[Unset, TableSqlConditionPassedPercentCheckSpec]):
    """

    daily_sql_condition_passed_percent_on_table: Union[
        Unset, "TableSqlConditionPassedPercentCheckSpec"
    ] = UNSET
    daily_sql_condition_failed_count_on_table: Union[
        Unset, "TableSqlConditionFailedCountCheckSpec"
    ] = UNSET
    daily_sql_aggregate_expr_table: Union[
        Unset, "TableSqlAggregateExprCheckSpec"
    ] = UNSET
    min_sql_condition_passed_percent_on_table: Union[
        Unset, "TableSqlConditionPassedPercentCheckSpec"
    ] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        daily_sql_condition_passed_percent_on_table: Union[
            Unset, Dict[str, Any]
        ] = UNSET
        if not isinstance(self.daily_sql_condition_passed_percent_on_table, Unset):
            daily_sql_condition_passed_percent_on_table = (
                self.daily_sql_condition_passed_percent_on_table.to_dict()
            )

        daily_sql_condition_failed_count_on_table: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.daily_sql_condition_failed_count_on_table, Unset):
            daily_sql_condition_failed_count_on_table = (
                self.daily_sql_condition_failed_count_on_table.to_dict()
            )

        daily_sql_aggregate_expr_table: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.daily_sql_aggregate_expr_table, Unset):
            daily_sql_aggregate_expr_table = (
                self.daily_sql_aggregate_expr_table.to_dict()
            )

        min_sql_condition_passed_percent_on_table: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.min_sql_condition_passed_percent_on_table, Unset):
            min_sql_condition_passed_percent_on_table = (
                self.min_sql_condition_passed_percent_on_table.to_dict()
            )

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if daily_sql_condition_passed_percent_on_table is not UNSET:
            field_dict[
                "daily_sql_condition_passed_percent_on_table"
            ] = daily_sql_condition_passed_percent_on_table
        if daily_sql_condition_failed_count_on_table is not UNSET:
            field_dict[
                "daily_sql_condition_failed_count_on_table"
            ] = daily_sql_condition_failed_count_on_table
        if daily_sql_aggregate_expr_table is not UNSET:
            field_dict[
                "daily_sql_aggregate_expr_table"
            ] = daily_sql_aggregate_expr_table
        if min_sql_condition_passed_percent_on_table is not UNSET:
            field_dict[
                "min_sql_condition_passed_percent_on_table"
            ] = min_sql_condition_passed_percent_on_table

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.table_sql_aggregate_expr_check_spec import (
            TableSqlAggregateExprCheckSpec,
        )
        from ..models.table_sql_condition_failed_count_check_spec import (
            TableSqlConditionFailedCountCheckSpec,
        )
        from ..models.table_sql_condition_passed_percent_check_spec import (
            TableSqlConditionPassedPercentCheckSpec,
        )

        d = src_dict.copy()
        _daily_sql_condition_passed_percent_on_table = d.pop(
            "daily_sql_condition_passed_percent_on_table", UNSET
        )
        daily_sql_condition_passed_percent_on_table: Union[
            Unset, TableSqlConditionPassedPercentCheckSpec
        ]
        if isinstance(_daily_sql_condition_passed_percent_on_table, Unset):
            daily_sql_condition_passed_percent_on_table = UNSET
        else:
            daily_sql_condition_passed_percent_on_table = (
                TableSqlConditionPassedPercentCheckSpec.from_dict(
                    _daily_sql_condition_passed_percent_on_table
                )
            )

        _daily_sql_condition_failed_count_on_table = d.pop(
            "daily_sql_condition_failed_count_on_table", UNSET
        )
        daily_sql_condition_failed_count_on_table: Union[
            Unset, TableSqlConditionFailedCountCheckSpec
        ]
        if isinstance(_daily_sql_condition_failed_count_on_table, Unset):
            daily_sql_condition_failed_count_on_table = UNSET
        else:
            daily_sql_condition_failed_count_on_table = (
                TableSqlConditionFailedCountCheckSpec.from_dict(
                    _daily_sql_condition_failed_count_on_table
                )
            )

        _daily_sql_aggregate_expr_table = d.pop("daily_sql_aggregate_expr_table", UNSET)
        daily_sql_aggregate_expr_table: Union[Unset, TableSqlAggregateExprCheckSpec]
        if isinstance(_daily_sql_aggregate_expr_table, Unset):
            daily_sql_aggregate_expr_table = UNSET
        else:
            daily_sql_aggregate_expr_table = TableSqlAggregateExprCheckSpec.from_dict(
                _daily_sql_aggregate_expr_table
            )

        _min_sql_condition_passed_percent_on_table = d.pop(
            "min_sql_condition_passed_percent_on_table", UNSET
        )
        min_sql_condition_passed_percent_on_table: Union[
            Unset, TableSqlConditionPassedPercentCheckSpec
        ]
        if isinstance(_min_sql_condition_passed_percent_on_table, Unset):
            min_sql_condition_passed_percent_on_table = UNSET
        else:
            min_sql_condition_passed_percent_on_table = (
                TableSqlConditionPassedPercentCheckSpec.from_dict(
                    _min_sql_condition_passed_percent_on_table
                )
            )

        table_sql_daily_recurring_checks_spec = cls(
            daily_sql_condition_passed_percent_on_table=daily_sql_condition_passed_percent_on_table,
            daily_sql_condition_failed_count_on_table=daily_sql_condition_failed_count_on_table,
            daily_sql_aggregate_expr_table=daily_sql_aggregate_expr_table,
            min_sql_condition_passed_percent_on_table=min_sql_condition_passed_percent_on_table,
        )

        table_sql_daily_recurring_checks_spec.additional_properties = d
        return table_sql_daily_recurring_checks_spec

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.column_strings_string_datatype_detect_statistics_collector_spec import (
        ColumnStringsStringDatatypeDetectStatisticsCollectorSpec,
    )
    from ..models.column_strings_string_max_length_statistics_collector_spec import (
        ColumnStringsStringMaxLengthStatisticsCollectorSpec,
    )
    from ..models.column_strings_string_mean_length_statistics_collector_spec import (
        ColumnStringsStringMeanLengthStatisticsCollectorSpec,
    )
    from ..models.column_strings_string_min_length_statistics_collector_spec import (
        ColumnStringsStringMinLengthStatisticsCollectorSpec,
    )


T = TypeVar("T", bound="ColumnStringsStatisticsCollectorsSpec")


@attr.s(auto_attribs=True)
class ColumnStringsStatisticsCollectorsSpec:
    """
    Attributes:
        string_max_length (Union[Unset, ColumnStringsStringMaxLengthStatisticsCollectorSpec]):
        string_mean_length (Union[Unset, ColumnStringsStringMeanLengthStatisticsCollectorSpec]):
        string_min_length (Union[Unset, ColumnStringsStringMinLengthStatisticsCollectorSpec]):
        string_datatype_detect (Union[Unset, ColumnStringsStringDatatypeDetectStatisticsCollectorSpec]):
    """

    string_max_length: Union[
        Unset, "ColumnStringsStringMaxLengthStatisticsCollectorSpec"
    ] = UNSET
    string_mean_length: Union[
        Unset, "ColumnStringsStringMeanLengthStatisticsCollectorSpec"
    ] = UNSET
    string_min_length: Union[
        Unset, "ColumnStringsStringMinLengthStatisticsCollectorSpec"
    ] = UNSET
    string_datatype_detect: Union[
        Unset, "ColumnStringsStringDatatypeDetectStatisticsCollectorSpec"
    ] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        string_max_length: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.string_max_length, Unset):
            string_max_length = self.string_max_length.to_dict()

        string_mean_length: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.string_mean_length, Unset):
            string_mean_length = self.string_mean_length.to_dict()

        string_min_length: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.string_min_length, Unset):
            string_min_length = self.string_min_length.to_dict()

        string_datatype_detect: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.string_datatype_detect, Unset):
            string_datatype_detect = self.string_datatype_detect.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if string_max_length is not UNSET:
            field_dict["string_max_length"] = string_max_length
        if string_mean_length is not UNSET:
            field_dict["string_mean_length"] = string_mean_length
        if string_min_length is not UNSET:
            field_dict["string_min_length"] = string_min_length
        if string_datatype_detect is not UNSET:
            field_dict["string_datatype_detect"] = string_datatype_detect

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.column_strings_string_datatype_detect_statistics_collector_spec import (
            ColumnStringsStringDatatypeDetectStatisticsCollectorSpec,
        )
        from ..models.column_strings_string_max_length_statistics_collector_spec import (
            ColumnStringsStringMaxLengthStatisticsCollectorSpec,
        )
        from ..models.column_strings_string_mean_length_statistics_collector_spec import (
            ColumnStringsStringMeanLengthStatisticsCollectorSpec,
        )
        from ..models.column_strings_string_min_length_statistics_collector_spec import (
            ColumnStringsStringMinLengthStatisticsCollectorSpec,
        )

        d = src_dict.copy()
        _string_max_length = d.pop("string_max_length", UNSET)
        string_max_length: Union[
            Unset, ColumnStringsStringMaxLengthStatisticsCollectorSpec
        ]
        if isinstance(_string_max_length, Unset):
            string_max_length = UNSET
        else:
            string_max_length = (
                ColumnStringsStringMaxLengthStatisticsCollectorSpec.from_dict(
                    _string_max_length
                )
            )

        _string_mean_length = d.pop("string_mean_length", UNSET)
        string_mean_length: Union[
            Unset, ColumnStringsStringMeanLengthStatisticsCollectorSpec
        ]
        if isinstance(_string_mean_length, Unset):
            string_mean_length = UNSET
        else:
            string_mean_length = (
                ColumnStringsStringMeanLengthStatisticsCollectorSpec.from_dict(
                    _string_mean_length
                )
            )

        _string_min_length = d.pop("string_min_length", UNSET)
        string_min_length: Union[
            Unset, ColumnStringsStringMinLengthStatisticsCollectorSpec
        ]
        if isinstance(_string_min_length, Unset):
            string_min_length = UNSET
        else:
            string_min_length = (
                ColumnStringsStringMinLengthStatisticsCollectorSpec.from_dict(
                    _string_min_length
                )
            )

        _string_datatype_detect = d.pop("string_datatype_detect", UNSET)
        string_datatype_detect: Union[
            Unset, ColumnStringsStringDatatypeDetectStatisticsCollectorSpec
        ]
        if isinstance(_string_datatype_detect, Unset):
            string_datatype_detect = UNSET
        else:
            string_datatype_detect = (
                ColumnStringsStringDatatypeDetectStatisticsCollectorSpec.from_dict(
                    _string_datatype_detect
                )
            )

        column_strings_statistics_collectors_spec = cls(
            string_max_length=string_max_length,
            string_mean_length=string_mean_length,
            string_min_length=string_min_length,
            string_datatype_detect=string_datatype_detect,
        )

        column_strings_statistics_collectors_spec.additional_properties = d
        return column_strings_statistics_collectors_spec

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

T = TypeVar("T", bound="CheckSpecBasicModel")


@attr.s(auto_attribs=True)
class CheckSpecBasicModel:
    """Check spec basic model

    Attributes:
        check_name (Union[Unset, str]): Check name
        full_check_name (Union[Unset, str]): Full check name
        custom (Union[Unset, bool]): This check has is a custom check or was customized by the user.
        built_in (Union[Unset, bool]): This check is provided with DQO as a built-in check.
    """

    check_name: Union[Unset, str] = UNSET
    full_check_name: Union[Unset, str] = UNSET
    custom: Union[Unset, bool] = UNSET
    built_in: Union[Unset, bool] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        check_name = self.check_name
        full_check_name = self.full_check_name
        custom = self.custom
        built_in = self.built_in

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if check_name is not UNSET:
            field_dict["check_name"] = check_name
        if full_check_name is not UNSET:
            field_dict["full_check_name"] = full_check_name
        if custom is not UNSET:
            field_dict["custom"] = custom
        if built_in is not UNSET:
            field_dict["built_in"] = built_in

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        check_name = d.pop("check_name", UNSET)

        full_check_name = d.pop("full_check_name", UNSET)

        custom = d.pop("custom", UNSET)

        built_in = d.pop("built_in", UNSET)

        check_spec_basic_model = cls(
            check_name=check_name,
            full_check_name=full_check_name,
            custom=custom,
            built_in=built_in,
        )

        check_spec_basic_model.additional_properties = d
        return check_spec_basic_model

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.table_volume_statistics_collectors_spec import (
        TableVolumeStatisticsCollectorsSpec,
    )


T = TypeVar("T", bound="TableStatisticsCollectorsRootCategoriesSpec")


@attr.s(auto_attribs=True)
class TableStatisticsCollectorsRootCategoriesSpec:
    """
    Attributes:
        volume (Union[Unset, TableVolumeStatisticsCollectorsSpec]):
    """

    volume: Union[Unset, "TableVolumeStatisticsCollectorsSpec"] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        volume: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.volume, Unset):
            volume = self.volume.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if volume is not UNSET:
            field_dict["volume"] = volume

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.table_volume_statistics_collectors_spec import (
            TableVolumeStatisticsCollectorsSpec,
        )

        d = src_dict.copy()
        _volume = d.pop("volume", UNSET)
        volume: Union[Unset, TableVolumeStatisticsCollectorsSpec]
        if isinstance(_volume, Unset):
            volume = UNSET
        else:
            volume = TableVolumeStatisticsCollectorsSpec.from_dict(_volume)

        table_statistics_collectors_root_categories_spec = cls(
            volume=volume,
        )

        table_statistics_collectors_root_categories_spec.additional_properties = d
        return table_statistics_collectors_root_categories_spec

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from http import HTTPStatus
from typing import Any, Dict, Optional

import httpx

from ... import errors
from ...client import Client
from ...models.table_incident_grouping_spec import TableIncidentGroupingSpec
from ...types import Response


def _get_kwargs(
    connection_name: str,
    schema_name: str,
    table_name: str,
    *,
    client: Client,
) -> Dict[str, Any]:
    url = "{}api/connections/{connectionName}/schemas/{schemaName}/tables/{tableName}/incidentgrouping".format(
        client.base_url,
        connectionName=connection_name,
        schemaName=schema_name,
        tableName=table_name,
    )

    headers: Dict[str, str] = client.get_headers()
    cookies: Dict[str, Any] = client.get_cookies()

    return {
        "method": "get",
        "url": url,
        "headers": headers,
        "cookies": cookies,
        "timeout": client.get_timeout(),
        "follow_redirects": client.follow_redirects,
    }


def _parse_response(
    *, client: Client, response: httpx.Response
) -> Optional[TableIncidentGroupingSpec]:
    if response.status_code == HTTPStatus.OK:
        response_200 = TableIncidentGroupingSpec.from_dict(response.json())

        return response_200
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(
    *, client: Client, response: httpx.Response
) -> Response[TableIncidentGroupingSpec]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    connection_name: str,
    schema_name: str,
    table_name: str,
    *,
    client: Client,
) -> Response[TableIncidentGroupingSpec]:
    """getTableIncidentGrouping

     Return the configuration of incident grouping on a table

    Args:
        connection_name (str):
        schema_name (str):
        table_name (str):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[TableIncidentGroupingSpec]
    """

    kwargs = _get_kwargs(
        connection_name=connection_name,
        schema_name=schema_name,
        table_name=table_name,
        client=client,
    )

    response = httpx.request(
        verify=client.verify_ssl,
        **kwargs,
    )

    return _build_response(client=client, response=response)


def sync(
    connection_name: str,
    schema_name: str,
    table_name: str,
    *,
    client: Client,
) -> Optional[TableIncidentGroupingSpec]:
    """getTableIncidentGrouping

     Return the configuration of incident grouping on a table

    Args:
        connection_name (str):
        schema_name (str):
        table_name (str):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        TableIncidentGroupingSpec
    """

    return sync_detailed(
        connection_name=connection_name,
        schema_name=schema_name,
        table_name=table_name,
        client=client,
    ).parsed


async def asyncio_detailed(
    connection_name: str,
    schema_name: str,
    table_name: str,
    *,
    client: Client,
) -> Response[TableIncidentGroupingSpec]:
    """getTableIncidentGrouping

     Return the configuration of incident grouping on a table

    Args:
        connection_name (str):
        schema_name (str):
        table_name (str):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[TableIncidentGroupingSpec]
    """

    kwargs = _get_kwargs(
        connection_name=connection_name,
        schema_name=schema_name,
        table_name=table_name,
        client=client,
    )

    async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
        response = await _client.request(**kwargs)

    return _build_response(client=client, response=response)


async def asyncio(
    connection_name: str,
    schema_name: str,
    table_name: str,
    *,
    client: Client,
) -> Optional[TableIncidentGroupingSpec]:
    """getTableIncidentGrouping

     Return the configuration of incident grouping on a table

    Args:
        connection_name (str):
        schema_name (str):
        table_name (str):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        TableIncidentGroupingSpec
    """

    return (
        await asyncio_detailed(
            connection_name=connection_name,
            schema_name=schema_name,
            table_name=table_name,
            client=client,
        )
    ).parsed



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.connection_spec import ConnectionSpec


T = TypeVar("T", bound="ConnectionModel")


@attr.s(auto_attribs=True)
class ConnectionModel:
    """Full connection model

    Attributes:
        connection_name (Union[Unset, str]): Connection name.
        connection_hash (Union[Unset, int]): Connection hash that identifies the connection using a unique hash code.
        spec (Union[Unset, ConnectionSpec]):
    """

    connection_name: Union[Unset, str] = UNSET
    connection_hash: Union[Unset, int] = UNSET
    spec: Union[Unset, "ConnectionSpec"] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        connection_name = self.connection_name
        connection_hash = self.connection_hash
        spec: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.spec, Unset):
            spec = self.spec.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if connection_name is not UNSET:
            field_dict["connection_name"] = connection_name
        if connection_hash is not UNSET:
            field_dict["connection_hash"] = connection_hash
        if spec is not UNSET:
            field_dict["spec"] = spec

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.connection_spec import ConnectionSpec

        d = src_dict.copy()
        connection_name = d.pop("connection_name", UNSET)

        connection_hash = d.pop("connection_hash", UNSET)

        _spec = d.pop("spec", UNSET)
        spec: Union[Unset, ConnectionSpec]
        if isinstance(_spec, Unset):
            spec = UNSET
        else:
            spec = ConnectionSpec.from_dict(_spec)

        connection_model = cls(
            connection_name=connection_name,
            connection_hash=connection_hash,
            spec=spec,
        )

        connection_model.additional_properties = d
        return connection_model

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.table_data_quality_status_model_failed_checks_statuses import (
        TableDataQualityStatusModelFailedChecksStatuses,
    )


T = TypeVar("T", bound="TableDataQualityStatusModel")


@attr.s(auto_attribs=True)
class TableDataQualityStatusModel:
    """The table's most recent data quality status. It is a summary of the results of the most recently executed data
    quality checks on the table. Verify the value of the highest_severity_issue (0 - all data quality checks passed, 1 -
    a warning was detected, 2 - an error was detected, 3 - a fatal data quality issue was detected.

        Attributes:
            connection_name (Union[Unset, str]): The connection name in DQO.
            schema_name (Union[Unset, str]): The schema name.
            table_name (Union[Unset, str]): The table name.
            highest_severity_issue (Union[Unset, int]): The severity of the highest identified data quality issue (1 =
                warning, 2 = error, 3 = fatal) or 0 when no data quality issues were identified. This field will be null if no
                data quality checks were executed on the table.
            last_check_executed_at (Union[Unset, int]): The UTC timestamp when the most recent data quality check was
                executed on the table.
            executed_checks (Union[Unset, int]): The total number of most recent checks that were executed on the table.
                Table comparison checks that are comparing groups of data are counted as the number of compared data groups.
            valid_results (Union[Unset, int]): The number of most recent valid data quality checks that passed without
                raising any issues.
            warnings (Union[Unset, int]): The number of most recent data quality checks that failed by raising a warning
                severity data quality issue.
            errors (Union[Unset, int]): The number of most recent data quality checks that failed by raising an error
                severity data quality issue.
            fatals (Union[Unset, int]): The number of most recent data quality checks that failed by raising a fatal
                severity data quality issue.
            execution_errors (Union[Unset, int]): The number of data quality check execution errors that were reported due
                to access issues to the data source, invalid mapping in DQO, invalid queries in data quality sensors or invalid
                python rules. When an execution error is reported, the configuration of a data quality check on a table must be
                updated.
            failed_checks_statuses (Union[Unset, TableDataQualityStatusModelFailedChecksStatuses]): The paths to all failed
                data quality checks (keys) and severity of the highest data quality issue that was detected. Table level checks
                are identified by the check name. Column level checks are identified as a check_name[column_name].
    """

    connection_name: Union[Unset, str] = UNSET
    schema_name: Union[Unset, str] = UNSET
    table_name: Union[Unset, str] = UNSET
    highest_severity_issue: Union[Unset, int] = UNSET
    last_check_executed_at: Union[Unset, int] = UNSET
    executed_checks: Union[Unset, int] = UNSET
    valid_results: Union[Unset, int] = UNSET
    warnings: Union[Unset, int] = UNSET
    errors: Union[Unset, int] = UNSET
    fatals: Union[Unset, int] = UNSET
    execution_errors: Union[Unset, int] = UNSET
    failed_checks_statuses: Union[
        Unset, "TableDataQualityStatusModelFailedChecksStatuses"
    ] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        connection_name = self.connection_name
        schema_name = self.schema_name
        table_name = self.table_name
        highest_severity_issue = self.highest_severity_issue
        last_check_executed_at = self.last_check_executed_at
        executed_checks = self.executed_checks
        valid_results = self.valid_results
        warnings = self.warnings
        errors = self.errors
        fatals = self.fatals
        execution_errors = self.execution_errors
        failed_checks_statuses: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.failed_checks_statuses, Unset):
            failed_checks_statuses = self.failed_checks_statuses.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if connection_name is not UNSET:
            field_dict["connection_name"] = connection_name
        if schema_name is not UNSET:
            field_dict["schema_name"] = schema_name
        if table_name is not UNSET:
            field_dict["table_name"] = table_name
        if highest_severity_issue is not UNSET:
            field_dict["highest_severity_issue"] = highest_severity_issue
        if last_check_executed_at is not UNSET:
            field_dict["last_check_executed_at"] = last_check_executed_at
        if executed_checks is not UNSET:
            field_dict["executed_checks"] = executed_checks
        if valid_results is not UNSET:
            field_dict["valid_results"] = valid_results
        if warnings is not UNSET:
            field_dict["warnings"] = warnings
        if errors is not UNSET:
            field_dict["errors"] = errors
        if fatals is not UNSET:
            field_dict["fatals"] = fatals
        if execution_errors is not UNSET:
            field_dict["execution_errors"] = execution_errors
        if failed_checks_statuses is not UNSET:
            field_dict["failed_checks_statuses"] = failed_checks_statuses

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.table_data_quality_status_model_failed_checks_statuses import (
            TableDataQualityStatusModelFailedChecksStatuses,
        )

        d = src_dict.copy()
        connection_name = d.pop("connection_name", UNSET)

        schema_name = d.pop("schema_name", UNSET)

        table_name = d.pop("table_name", UNSET)

        highest_severity_issue = d.pop("highest_severity_issue", UNSET)

        last_check_executed_at = d.pop("last_check_executed_at", UNSET)

        executed_checks = d.pop("executed_checks", UNSET)

        valid_results = d.pop("valid_results", UNSET)

        warnings = d.pop("warnings", UNSET)

        errors = d.pop("errors", UNSET)

        fatals = d.pop("fatals", UNSET)

        execution_errors = d.pop("execution_errors", UNSET)

        _failed_checks_statuses = d.pop("failed_checks_statuses", UNSET)
        failed_checks_statuses: Union[
            Unset, TableDataQualityStatusModelFailedChecksStatuses
        ]
        if isinstance(_failed_checks_statuses, Unset):
            failed_checks_statuses = UNSET
        else:
            failed_checks_statuses = (
                TableDataQualityStatusModelFailedChecksStatuses.from_dict(
                    _failed_checks_statuses
                )
            )

        table_data_quality_status_model = cls(
            connection_name=connection_name,
            schema_name=schema_name,
            table_name=table_name,
            highest_severity_issue=highest_severity_issue,
            last_check_executed_at=last_check_executed_at,
            executed_checks=executed_checks,
            valid_results=valid_results,
            warnings=warnings,
            errors=errors,
            fatals=fatals,
            execution_errors=execution_errors,
            failed_checks_statuses=failed_checks_statuses,
        )

        table_data_quality_status_model.additional_properties = d
        return table_data_quality_status_model

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from enum import Enum


class CheckConfigurationModelCheckType(str, Enum):
    PARTITIONED = "partitioned"
    PROFILING = "profiling"
    RECURRING = "recurring"

    def __str__(self) -> str:
        return str(self.value)



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.column_accuracy_total_average_match_percent_check_spec import (
        ColumnAccuracyTotalAverageMatchPercentCheckSpec,
    )
    from ..models.column_accuracy_total_max_match_percent_check_spec import (
        ColumnAccuracyTotalMaxMatchPercentCheckSpec,
    )
    from ..models.column_accuracy_total_min_match_percent_check_spec import (
        ColumnAccuracyTotalMinMatchPercentCheckSpec,
    )
    from ..models.column_accuracy_total_not_null_count_match_percent_check_spec import (
        ColumnAccuracyTotalNotNullCountMatchPercentCheckSpec,
    )
    from ..models.column_accuracy_total_sum_match_percent_check_spec import (
        ColumnAccuracyTotalSumMatchPercentCheckSpec,
    )


T = TypeVar("T", bound="ColumnAccuracyMonthlyRecurringChecksSpec")


@attr.s(auto_attribs=True)
class ColumnAccuracyMonthlyRecurringChecksSpec:
    """
    Attributes:
        monthly_total_sum_match_percent (Union[Unset, ColumnAccuracyTotalSumMatchPercentCheckSpec]):
        monthly_total_min_match_percent (Union[Unset, ColumnAccuracyTotalMinMatchPercentCheckSpec]):
        monthly_total_max_match_percent (Union[Unset, ColumnAccuracyTotalMaxMatchPercentCheckSpec]):
        monthly_total_average_match_percent (Union[Unset, ColumnAccuracyTotalAverageMatchPercentCheckSpec]):
        monthly_total_not_null_count_match_percent (Union[Unset, ColumnAccuracyTotalNotNullCountMatchPercentCheckSpec]):
    """

    monthly_total_sum_match_percent: Union[
        Unset, "ColumnAccuracyTotalSumMatchPercentCheckSpec"
    ] = UNSET
    monthly_total_min_match_percent: Union[
        Unset, "ColumnAccuracyTotalMinMatchPercentCheckSpec"
    ] = UNSET
    monthly_total_max_match_percent: Union[
        Unset, "ColumnAccuracyTotalMaxMatchPercentCheckSpec"
    ] = UNSET
    monthly_total_average_match_percent: Union[
        Unset, "ColumnAccuracyTotalAverageMatchPercentCheckSpec"
    ] = UNSET
    monthly_total_not_null_count_match_percent: Union[
        Unset, "ColumnAccuracyTotalNotNullCountMatchPercentCheckSpec"
    ] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        monthly_total_sum_match_percent: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.monthly_total_sum_match_percent, Unset):
            monthly_total_sum_match_percent = (
                self.monthly_total_sum_match_percent.to_dict()
            )

        monthly_total_min_match_percent: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.monthly_total_min_match_percent, Unset):
            monthly_total_min_match_percent = (
                self.monthly_total_min_match_percent.to_dict()
            )

        monthly_total_max_match_percent: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.monthly_total_max_match_percent, Unset):
            monthly_total_max_match_percent = (
                self.monthly_total_max_match_percent.to_dict()
            )

        monthly_total_average_match_percent: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.monthly_total_average_match_percent, Unset):
            monthly_total_average_match_percent = (
                self.monthly_total_average_match_percent.to_dict()
            )

        monthly_total_not_null_count_match_percent: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.monthly_total_not_null_count_match_percent, Unset):
            monthly_total_not_null_count_match_percent = (
                self.monthly_total_not_null_count_match_percent.to_dict()
            )

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if monthly_total_sum_match_percent is not UNSET:
            field_dict[
                "monthly_total_sum_match_percent"
            ] = monthly_total_sum_match_percent
        if monthly_total_min_match_percent is not UNSET:
            field_dict[
                "monthly_total_min_match_percent"
            ] = monthly_total_min_match_percent
        if monthly_total_max_match_percent is not UNSET:
            field_dict[
                "monthly_total_max_match_percent"
            ] = monthly_total_max_match_percent
        if monthly_total_average_match_percent is not UNSET:
            field_dict[
                "monthly_total_average_match_percent"
            ] = monthly_total_average_match_percent
        if monthly_total_not_null_count_match_percent is not UNSET:
            field_dict[
                "monthly_total_not_null_count_match_percent"
            ] = monthly_total_not_null_count_match_percent

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.column_accuracy_total_average_match_percent_check_spec import (
            ColumnAccuracyTotalAverageMatchPercentCheckSpec,
        )
        from ..models.column_accuracy_total_max_match_percent_check_spec import (
            ColumnAccuracyTotalMaxMatchPercentCheckSpec,
        )
        from ..models.column_accuracy_total_min_match_percent_check_spec import (
            ColumnAccuracyTotalMinMatchPercentCheckSpec,
        )
        from ..models.column_accuracy_total_not_null_count_match_percent_check_spec import (
            ColumnAccuracyTotalNotNullCountMatchPercentCheckSpec,
        )
        from ..models.column_accuracy_total_sum_match_percent_check_spec import (
            ColumnAccuracyTotalSumMatchPercentCheckSpec,
        )

        d = src_dict.copy()
        _monthly_total_sum_match_percent = d.pop(
            "monthly_total_sum_match_percent", UNSET
        )
        monthly_total_sum_match_percent: Union[
            Unset, ColumnAccuracyTotalSumMatchPercentCheckSpec
        ]
        if isinstance(_monthly_total_sum_match_percent, Unset):
            monthly_total_sum_match_percent = UNSET
        else:
            monthly_total_sum_match_percent = (
                ColumnAccuracyTotalSumMatchPercentCheckSpec.from_dict(
                    _monthly_total_sum_match_percent
                )
            )

        _monthly_total_min_match_percent = d.pop(
            "monthly_total_min_match_percent", UNSET
        )
        monthly_total_min_match_percent: Union[
            Unset, ColumnAccuracyTotalMinMatchPercentCheckSpec
        ]
        if isinstance(_monthly_total_min_match_percent, Unset):
            monthly_total_min_match_percent = UNSET
        else:
            monthly_total_min_match_percent = (
                ColumnAccuracyTotalMinMatchPercentCheckSpec.from_dict(
                    _monthly_total_min_match_percent
                )
            )

        _monthly_total_max_match_percent = d.pop(
            "monthly_total_max_match_percent", UNSET
        )
        monthly_total_max_match_percent: Union[
            Unset, ColumnAccuracyTotalMaxMatchPercentCheckSpec
        ]
        if isinstance(_monthly_total_max_match_percent, Unset):
            monthly_total_max_match_percent = UNSET
        else:
            monthly_total_max_match_percent = (
                ColumnAccuracyTotalMaxMatchPercentCheckSpec.from_dict(
                    _monthly_total_max_match_percent
                )
            )

        _monthly_total_average_match_percent = d.pop(
            "monthly_total_average_match_percent", UNSET
        )
        monthly_total_average_match_percent: Union[
            Unset, ColumnAccuracyTotalAverageMatchPercentCheckSpec
        ]
        if isinstance(_monthly_total_average_match_percent, Unset):
            monthly_total_average_match_percent = UNSET
        else:
            monthly_total_average_match_percent = (
                ColumnAccuracyTotalAverageMatchPercentCheckSpec.from_dict(
                    _monthly_total_average_match_percent
                )
            )

        _monthly_total_not_null_count_match_percent = d.pop(
            "monthly_total_not_null_count_match_percent", UNSET
        )
        monthly_total_not_null_count_match_percent: Union[
            Unset, ColumnAccuracyTotalNotNullCountMatchPercentCheckSpec
        ]
        if isinstance(_monthly_total_not_null_count_match_percent, Unset):
            monthly_total_not_null_count_match_percent = UNSET
        else:
            monthly_total_not_null_count_match_percent = (
                ColumnAccuracyTotalNotNullCountMatchPercentCheckSpec.from_dict(
                    _monthly_total_not_null_count_match_percent
                )
            )

        column_accuracy_monthly_recurring_checks_spec = cls(
            monthly_total_sum_match_percent=monthly_total_sum_match_percent,
            monthly_total_min_match_percent=monthly_total_min_match_percent,
            monthly_total_max_match_percent=monthly_total_max_match_percent,
            monthly_total_average_match_percent=monthly_total_average_match_percent,
            monthly_total_not_null_count_match_percent=monthly_total_not_null_count_match_percent,
        )

        column_accuracy_monthly_recurring_checks_spec.additional_properties = d
        return column_accuracy_monthly_recurring_checks_spec

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
